(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    106810,       2195]*)
(*NotebookOutlinePosition[    107771,       2224]*)
(*  CellTagsIndexPosition[    107727,       2220]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Linear Regression", "Title"],

Cell["\<\
Michael Goerz
10.09.2005\
\>", "Text"],

Cell[CellGroupData[{

Cell["Preamble", "Section"],

Cell[CellGroupData[{

Cell["Options", "Subsubsection"],

Cell[BoxData[
    \(\(SetDirectory["\</home/goerz/GP2/SPL\>"];\)\)], "Input"],

Cell[BoxData[
    \(\(Off[General::"\<spell1\>"];\)\)], "Input"],

Cell[BoxData[
    \(<< \ Statistics`DataManipulation`\)], "Input"],

Cell[BoxData[
    \(<< \ Graphics`Graphics`\)], "Input"],

Cell[BoxData[
    \(<< Statistics`LinearRegression`\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Some Regular Expressions (As Reference)", "Subsubsection"],

Cell[TextData[{
  "The following shell commands can be useful for filtering datafiles:\n\n",
  StyleBox["grep '[.0-9]\\|^#\\|^[[:space:]]$' data.csv", "Program"],
  "\nThis leaves any lines with data, gnuplot comment lines, and blank lines\n\
\n",
  StyleBox["grep '[.0-9]\\|^[[:space:]]$' data.csv", "Program"],
  "\nThis leaves any lines with data, and blank lines\n\n",
  StyleBox["grep '[.0-9]' data.csv", "Program"],
  "\nThis leaves only lines with data"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Initialization", "Subsubsection"],

Cell["\<\
Data is loaded from the file 'data.csv'. The file ist assumed to \
contain three collumns, the x-value, the y-value, and the y-error\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(dataset = ReadList["\<data_r1.csv\>", {Real, Real, \ Real}]\)], "Input"],

Cell[BoxData[
    \({{2.56`, 100.`, 18.29`}, {2.82`, 110.`, 19.13`}, {3.13`, 120.`, 
        20.08`}, {3.39`, 130.`, 20.85`}, {3.65`, 140.`, 21.62`}, {3.88`, 
        150.`, 22.31`}, {4.24`, 160.`, 23.31`}, {4.45`, 170.`, 
        23.91`}, {4.58`, 180.`, 24.31`}, {4.88`, 190.`, 25.13`}, {5.29`, 
        200.`, 26.16`}, {5.34`, 210.`, 26.37`}, {5.66`, 220.`, 
        27.21`}, {5.95`, 230.`, 27.95`}, {6.1`, 240.`, 28.37`}, {6.4`, 250.`, 
        29.12`}, {6.66`, 260.`, 29.77`}, {6.86`, 270.`, 30.31`}, {7.18`, 
        280.`, 31.08`}, {7.62`, 290.`, 32.08`}, {7.84`, 300.`, 
        32.63`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dataset2 = ReadList["\<data_r2.csv\>", {Real, Real, \ Real}]\)], "Input"],

Cell[BoxData[
    \({{1.32`, 100.`, 21.55`}, {1.54`, 110.`, 23.06`}, {1.72`, 120.`, 
        24.27`}, {1.8`, 130.`, 24.85`}, {1.9`, 140.`, 25.6`}, {2.04`, 150.`, 
        26.52`}, {2.22`, 160.`, 27.62`}, {2.4`, 170.`, 28.73`}, {2.46`, 
        180.`, 29.16`}, {2.62`, 190.`, 30.12`}, {2.76`, 200.`, 
        30.9`}, {2.92`, 210.`, 31.87`}, {3.06`, 220.`, 32.67`}, {3.17`, 
        230.`, 33.3`}, {3.31`, 240.`, 34.11`}, {3.39`, 250.`, 
        34.57`}, {3.61`, 260.`, 35.75`}, {3.76`, 270.`, 36.58`}, {3.92`, 
        280.`, 37.41`}, {4.12`, 290.`, 38.43`}, {4.2`, 300.`, 
        38.9`}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dataset3 = ReadList["\<data_r3.csv\>", {Real, Real, \ Real}]\)], "Input"],

Cell[BoxData[
    \({{0.81`, 100.`, 24.68`}, {0.88`, 110.`, 25.71`}, {1.`, 120.`, 
        27.23`}, {1.14`, 130.`, 29.01`}, {1.21`, 140.`, 29.84`}, {1.32`, 
        150.`, 31.16`}, {1.42`, 160.`, 32.25`}, {1.51`, 170.`, 
        33.34`}, {1.59`, 180.`, 34.2`}, {1.66`, 190.`, 35.06`}, {1.77`, 
        200.`, 36.18`}, {1.88`, 210.`, 37.3`}, {1.9`, 220.`, 37.66`}, {1.99`, 
        230.`, 38.54`}, {2.1`, 240.`, 39.69`}, {2.16`, 250.`, 
        40.31`}, {2.25`, 260.`, 41.2`}, {2.37`, 270.`, 42.37`}, {2.5`, 280.`, 
        43.54`}, {2.59`, 290.`, 44.45`}, {2.62`, 300.`, 44.83`}}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["Standard Functions for Linear Regression", "Subsubsection"],

Cell[BoxData[
    RowBox[{\(LinReg[daten_]\), ":=", " ", "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, \[CapitalDelta]y, \ 
            S\ , \[CapitalDelta]a0, \[CapitalDelta]b0, \ a0, \ b0, n, 
            Rsqared0, \[Chi]Squared0}\), ",", "\[IndentingNewLine]", 
          
          RowBox[{\(n = Length[daten]\), ";", 
            "\[IndentingNewLine]", \(x = Column[daten, 1]\), ";", 
            "\[IndentingNewLine]", \(y = Column[daten, \ 2]\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]y = Column[daten, 3]\), 
            ";", "\[IndentingNewLine]", \(S = \[Sum]\+\(i = 1\)\%n\( 
                        1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\((x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \((\[Sum]\+\(i = 1\)\%n \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\^2\), ";", 
            "\[IndentingNewLine]", \(a0 = \(1\/S\) \((\[Sum]\+\(i = \
1\)\%n\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\
\(i = 1\)\%n y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( 
                              x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\
\[LeftDoubleBracket]i\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\))\)\), ";", 
            RowBox[{
              RowBox[{Cell[""], "b0"}], 
              "=", \(\(1\/S\) \((\[Sum]\+\(i = 1\)\%n\( 
                            1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]i\
\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \[Sum]\+\
\(i = 1\)\%n\( 
                              x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\(\(\
\ \)\(y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\)\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)}], ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]a0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = \
1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]\
y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)\)\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]b0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = 1\)\%n 1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)\)\), ";", 
            "\[IndentingNewLine]", \(Rsqared0 = 
              1 - \((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)/\
\((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - \((\
\[Sum]\+\(i = 1\)\%n\( y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\
\(i = 1\)\%n \
1\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\))\)\
\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\),
             ";", "\[IndentingNewLine]", \(\[Chi]Sqared0 = \[Sum]\+\(i = \
1\)\%n\((\(1\/\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket]\) \
\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - b0\ x\
\[LeftDoubleBracket]i\[RightDoubleBracket])\))\)\^2\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<Errors from dataset\>"]\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<Number of data points: \>", 
              n]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print[
              
              TableForm[{{"\<\>", "\<Value\>", \ "\<Error\>"}, {"\<Slope \
b\>", \ b0, \ \[CapitalDelta]b0}, {"\<y-Intercept a\>", \ 
                    a0, \ \[CapitalDelta]a0}}]]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\>"]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of best fit: y = \>", 
              b0, "\< * x + \>", a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of top worst fit: y = \
\>", b0 + \[CapitalDelta]b0, "\< * x +\>", \ a0 + \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of bottom worst fit: y \
= \>", b0 - \[CapitalDelta]b0, "\< * x + \>", a0 - \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Certainty Measure \
\!\(R\^2\): \>\"", \ Rsqared0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Quality of the \
Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 2\)\): \>\"", \[Chi]Sqared0\/\(n - \
2\)]\), ";", 
            "\[IndentingNewLine]", \( (*Error\ too\ small\ if\ s\^2\  > \ 
                0, \ Error\ too\ large\ if\ s\^2\  < \ 0*) \), 
            "\[IndentingNewLine]", 
            "\[IndentingNewLine]", \({b \[Rule] \ 
                b0, \ \[CapitalDelta]b\  \[Rule] \ \[CapitalDelta]b0, \ 
              a \[Rule] \ 
                a0, \ \[CapitalDelta]a \[Rule] \ \[CapitalDelta]a0, \ 
              Rsqared \[Rule] \ 
                Rsqared0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]Sqared0, \ 
              sSquared\  \[Rule] \[Chi]Sqared0\/\(n - 2\)\ }\)}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Regression with Error Taken from Weighted Variance", \
"Subsubsection"],

Cell[BoxData[
    RowBox[{\(LinRegWeightedVariance[daten_]\), ":=", " ", 
      "\[IndentingNewLine]", 
      RowBox[{"Module", "[", 
        RowBox[{\({x, y, f, \ S\ , \[CapitalDelta]a0, \[CapitalDelta]b0, \ 
            a0, \ b0, n, Rsqared0, \ \[Chi]Sqared0}\), ",", 
          "\[IndentingNewLine]", 
          
          RowBox[{\(n = Length[daten]\), ";", 
            "\[IndentingNewLine]", \(x = Column[daten, 1]\), ";", 
            "\[IndentingNewLine]", \(y = Column[daten, \ 2]\), ";", 
            "\[IndentingNewLine]", \( (*Fuer\ die\ f\_i\ muessen\ die\ \
\[CapitalDelta]y\_i\ verwendet\ werden*) \), 
            "\[IndentingNewLine]", \(f = Column[daten, 3]\), ";", 
            "\[IndentingNewLine]", \(S = \[Sum]\+\(i = 1\)\%n\( 
                        1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^\
2\) \(\[Sum]\+\(i = \
1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \((\[Sum]\+\(i = 1\)\%n \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2)\)\^2\), ";", 
            "\[IndentingNewLine]", \(a0 = \(1\/S\) \((\[Sum]\+\(i = \
1\)\%n\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n y\
\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]\
i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( \
x\[LeftDoubleBracket]i\[RightDoubleBracket]\ y\[LeftDoubleBracket]i\
\[RightDoubleBracket]\)\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\
\))\)\), ";", 
            RowBox[{
              RowBox[{Cell[""], "b0"}], 
              "=", \(\(1\/S\) \((\[Sum]\+\(i = 1\)\%n\( 
                            1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\) \(\[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]i\[RightDoubleBracket]\ \
y\[LeftDoubleBracket]i\[RightDoubleBracket]\)\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\) - \[Sum]\+\(i = 1\)\%n\( x\[LeftDoubleBracket]
                              i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]\
i\[RightDoubleBracket])\)\^2\) \(\[Sum]\+\(i = 1\)\%n\(\(\ \)\(y\
\[LeftDoubleBracket]i\[RightDoubleBracket]\)\)\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\))\)\)}], ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]a0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = \
1\)\%n\((\(\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) \(1\/\(n - 2\)\) \
\(\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - \
b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)\)\), ";", 
            "\[IndentingNewLine]", \(\[CapitalDelta]b0 = \@\(\(1\/S\) \
\(\[Sum]\+\(i = 1\)\%n\((\(1\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\) \(1\/\(n - 2\)\) \(\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\)\)\)\), ";", 
            "\[IndentingNewLine]", \(Rsqared0 = 
              1 - \((\[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\[RightDoubleBracket])\
\)\^2\/\((f\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)/\((\[Sum]\+\(i \
= 1\)\%n\((y\[LeftDoubleBracket]i\[RightDoubleBracket] - \((\[Sum]\+\(i = 1\)\
\%n\( y\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((f\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n 1\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\))\))\)\^2\/\((f\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\), ";", 
            "\[IndentingNewLine]", \(\[Chi]Sqared0 = \[Sum]\+\(i = \
1\)\%n\((\(1\/f\[LeftDoubleBracket]i\[RightDoubleBracket]\) \((y\
\[LeftDoubleBracket]i\[RightDoubleBracket] - a0 - b0\ x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\))\)\^2\), ";", 
            "\[IndentingNewLine]", \(Print["\<Errors from variance\>"]\), ";",
             "\n", "\[IndentingNewLine]", \(Print["\<Number of data points: \
\>", n]\), ";", "\n", 
            "\[IndentingNewLine]", \(Print[
              TableForm[{{"\<\>", "\<Value\>", \ "\<Error\>"}, {"\<Slope \
b\>", \ b0, \ \[CapitalDelta]b0}, {"\<y-Intercept a\>", \ 
                    a0, \ \[CapitalDelta]a0}}]]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\>"]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of best fit: y = \>", 
              b0, "\< * x + \>", a0]\), 
            ";", \(Print["\<Equation of top worst fit: y = \>", 
              b0 + \[CapitalDelta]b0, "\< * x + \>", 
              a0 + \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<Equation of bottom worst fit: y \
= \>", b0 - \[CapitalDelta]b0, "\< * x + \>", a0 - \[CapitalDelta]a0]\), ";", 
            "\[IndentingNewLine]", \(Print["\<\n\>", \*"\"\<Quality of the \
Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 2\)\): \>\"", \[Chi]Sqared0\/\(n - \
2\)]\), ";", \(Print["\<\n\>", \*"\"\<Certainty Measure \!\(R\^2\): \>\"", \ 
              Rsqared0]\), ";", 
            "\n", \( (*Error\ too\ small\ if\ s\^2\  > \ 0, \ 
              Error\ too\ large\ if\ s\^2\  < \ 0*) \), "\[IndentingNewLine]",
             "\[IndentingNewLine]", \({b \[Rule] \ 
                b0, \ \[CapitalDelta]b\  \[Rule] \ \[CapitalDelta]b0, \ 
              a \[Rule] \ 
                a0, \ \[CapitalDelta]a \[Rule] \ \[CapitalDelta]a0, \ 
              Rsqared \[Rule] \ 
                Rsqared0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]Sqared0, 
              sSquared\  \[Rule] \[Chi]Sqared0\/\(n - 2\)}\)}]}], 
        "\[IndentingNewLine]", "\[IndentingNewLine]", "]"}]}]], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Linear Regression for a Straight Line from the Origin", "Subsubsection"],

Cell[BoxData[
    \(LinRegOrigin[
        daten_] := \[IndentingNewLine]Module[{x, y, \[CapitalDelta]y, 
          S, \[CapitalDelta]b0, b0, n, ybar0, 
          Rsq0, \[Chi]sq0}, \[IndentingNewLine]n = 
          Length[daten]; \[IndentingNewLine]x = 
          Column[daten, 1]; \[IndentingNewLine]y = 
          Column[daten, 2]; \[IndentingNewLine]\[CapitalDelta]y = 
          Column[daten, 
            3]; \[IndentingNewLine]S = \[Sum]\+\(i = 1\)\%n 1\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2*\(\[Sum]\+\(\
i = 1\)\%n\((x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\) - \
\((\[Sum]\+\(i = 1\)\%n x\[LeftDoubleBracket]i\[RightDoubleBracket]\/\((\
\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2)\)\^2; \
\[IndentingNewLine]b0 = \[Sum]\+\(i = 1\)\%n\(\( x\[LeftDoubleBracket]
                      i\[RightDoubleBracket]*
                    y\[LeftDoubleBracket]
                      i\[RightDoubleBracket]\)\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n\((x\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)\ ; \[IndentingNewLine]\
\[CapitalDelta]b0 = 
          Sqrt[1/\(\[Sum]\+\(i = 1\)\%n\((x\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\[LeftDoubleBracket]i\
\[RightDoubleBracket])\)\^2\)]; \[IndentingNewLine]ybar0 = \[Sum]\+\(i = \
1\)\%n\( y\[LeftDoubleBracket]
                    i\[RightDoubleBracket]\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n 1\/\
\((\[CapitalDelta]y\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\); \
\[IndentingNewLine]Rsq0 = 
          1 - \[Sum]\+\(i = 1\)\%n\(\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - \
b0*x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\)/\(\[Sum]\+\(i = 1\)\%n\((y\
\[LeftDoubleBracket]i\[RightDoubleBracket] - ybar0)\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\); \
\[IndentingNewLine]\[Chi]sq0 = \[Sum]\+\(i = 1\)\%n\((y\[LeftDoubleBracket]i\
\[RightDoubleBracket] - \
b0*x\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2\/\((\[CapitalDelta]y\
\[LeftDoubleBracket]i\[RightDoubleBracket])\)\^2; \
\[IndentingNewLine]Print["\<Errors from dataset\>"]; \
\[IndentingNewLine]Print["\<Number of data points: \>", 
          n]; \[IndentingNewLine]Print[
          TableForm[{{"\<\>", "\<Value\>", "\<Error\>"}, {"\<Slope b\>", 
                b0, \[CapitalDelta]b0}}]]; \[IndentingNewLine]Print["\<\>"]; \
\[IndentingNewLine]Print["\<Equation of best fit: y = \>", 
          b0, "\< * x\>"]; \[IndentingNewLine]Print["\<Equation of top worst \
fit: y = \>", 
          b0 + \[CapitalDelta]b0, "\< * x\>"]; \
\[IndentingNewLine]Print["\<Equation of bottom worst fit: y = \>", 
          b0 - \[CapitalDelta]b0, "\< * x\>"]; \
\[IndentingNewLine]Print["\<\>"]; \[IndentingNewLine]Print[\*"\"\<Certainty \
Measure \!\(R\^2\): \>\"", 
          Rsq0]; \[IndentingNewLine]Print[\*"\"\<Quality of Errors \
\!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): \>\"", \[Chi]sq0\/\(n - 1\)]; \ \
\[IndentingNewLine]{a \[Rule] 0, \[CapitalDelta]a \[Rule] \ 0, 
          b -> \ b0, \ \[CapitalDelta]b -> \[CapitalDelta]b0, 
          Rsqared -> Rsq0, \ \[Chi]Sqared\  \[Rule] \ \[Chi]sq0, 
          sSquared\  \[Rule] \[Chi]sq0\/\(n - 2\)}\[IndentingNewLine]]\)], \
"Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Instructions for Exponential Data", "Subsubsection"],

Cell["\<\
It is best to linearize exponential data first with the following \
command:\
\>", "Text"],

Cell[BoxData[
    \(\(linearize[expdata_] := 
        Replace[expdata, {xi_, yi_, \[CapitalDelta]yi_} \[Rule] \ {xi, 
              Log[yi], \((1/yi)\)*\[CapitalDelta]yi}, 2];\)\)], "Input"],

Cell["\<\
Then, you can apply the functions for linear data. If you want to \
plot the data as exponential functions later, simply raise the full right \
hand side of the fit equation into the exponent.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exporting Data", "Subsubsection"],

Cell[TextData[{
  "To export data to a file, use\n",
  Cell[BoxData[
      \(Export["\<data.csv\>", dataset, \ "\<Table\>"]\)], "Input"]
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Application", "Section"],

Cell[CellGroupData[{

Cell["Calculation", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(parameter = LinRegOrigin[dataset]\)], "Input"],

Cell[BoxData[
    \("Errors from dataset"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of data points: "\[InvisibleSpace]21\),
      SequenceForm[ "Number of data points: ", 21],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Value\"\>", "\<\"Error\"\>"},
          {"\<\"Slope b\"\>", "38.71539471826054`", "1.1006006992168949`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of best fit: y = \
"\[InvisibleSpace]38.71539471826054`\[InvisibleSpace]" * x"\),
      SequenceForm[ "Equation of best fit: y = ", 38.715394718260541, " * x"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of top worst fit: y = \
"\[InvisibleSpace]39.81599541747744`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of top worst fit: y = ", 39.815995417477438, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of bottom worst fit: y = \
"\[InvisibleSpace]37.61479401904364`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of bottom worst fit: y = ", 37.614794019043643, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Certainty Measure \!\(R\^2\): \
"\[InvisibleSpace]0.998280288130061`\),
      SequenceForm[ "Certainty Measure \!\(R\^2\): ", 0.99828028813006098],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - \
1\)\): "\[InvisibleSpace]0.010546478181418968`\),
      SequenceForm[ 
      "Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): ", 
        0.010546478181418968],
      Editable->False]], "Print"],

Cell[BoxData[
    \({a \[Rule] 0, \[CapitalDelta]a \[Rule] 0, 
      b \[Rule] 38.71539471826054`, \[CapitalDelta]b \[Rule] 
        1.1006006992168949`, 
      Rsqared \[Rule] 0.998280288130061`, \[Chi]Sqared \[Rule] 
        0.21092956362837936`, 
      sSquared \[Rule] 0.011101555980441019`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(parameter2 = LinRegOrigin[dataset2]\)], "Input"],

Cell[BoxData[
    \("Errors from dataset"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of data points: "\[InvisibleSpace]21\),
      SequenceForm[ "Number of data points: ", 21],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Value\"\>", "\<\"Error\"\>"},
          {"\<\"Slope b\"\>", "72.1194824358202`", "2.453205003833028`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of best fit: y = \
"\[InvisibleSpace]72.1194824358202`\[InvisibleSpace]" * x"\),
      SequenceForm[ "Equation of best fit: y = ", 72.119482435820203, " * x"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of top worst fit: y = \
"\[InvisibleSpace]74.57268743965324`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of top worst fit: y = ", 74.572687439653237, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of bottom worst fit: y = \
"\[InvisibleSpace]69.66627743198717`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of bottom worst fit: y = ", 69.666277431987169, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Certainty Measure \!\(R\^2\): \
"\[InvisibleSpace]0.9976430340322591`\),
      SequenceForm[ "Certainty Measure \!\(R\^2\): ", 0.99764303403225907],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - \
1\)\): "\[InvisibleSpace]0.010109676914374262`\),
      SequenceForm[ 
      "Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): ", 
        0.010109676914374262],
      Editable->False]], "Print"],

Cell[BoxData[
    \({a \[Rule] 0, \[CapitalDelta]a \[Rule] 0, 
      b \[Rule] 72.1194824358202`, \[CapitalDelta]b \[Rule] 
        2.453205003833028`, 
      Rsqared \[Rule] 0.9976430340322591`, \[Chi]Sqared \[Rule] 
        0.20219353828748524`, 
      sSquared \[Rule] 0.010641765173025538`}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(parameter3 = LinRegOrigin[dataset3]\)], "Input"],

Cell[BoxData[
    \("Errors from dataset"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Number of data points: "\[InvisibleSpace]21\),
      SequenceForm[ "Number of data points: ", 21],
      Editable->False]], "Print"],

Cell[BoxData[
    TagBox[GridBox[{
          {"\<\"\"\>", "\<\"Value\"\>", "\<\"Error\"\>"},
          {"\<\"Slope b\"\>", "114.53368751548979`", "4.517147958599848`"}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      Function[ BoxForm`e$, 
        TableForm[ BoxForm`e$]]]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of best fit: y = \
"\[InvisibleSpace]114.53368751548979`\[InvisibleSpace]" * x"\),
      SequenceForm[ "Equation of best fit: y = ", 114.53368751548979, " * x"],
      
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of top worst fit: y = \
"\[InvisibleSpace]119.05083547408964`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of top worst fit: y = ", 119.05083547408964, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Equation of bottom worst fit: y = \
"\[InvisibleSpace]110.01653955688994`\[InvisibleSpace]" * x"\),
      SequenceForm[ 
      "Equation of bottom worst fit: y = ", 110.01653955688994, " * x"],
      Editable->False]], "Print"],

Cell[BoxData[
    \(\*"\<\"\"\>"\)], "Print"],

Cell[BoxData[
    InterpretationBox[\("Certainty Measure \!\(R\^2\): \
"\[InvisibleSpace]0.9944234892175774`\),
      SequenceForm[ "Certainty Measure \!\(R\^2\): ", 0.99442348921757739],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - \
1\)\): "\[InvisibleSpace]0.018093866599412155`\),
      SequenceForm[ 
      "Quality of Errors \!\(s\^2\)=\!\(\[Chi]\^2\/\(n - 1\)\): ", 
        0.018093866599412155],
      Editable->False]], "Print"],

Cell[BoxData[
    \({a \[Rule] 0, \[CapitalDelta]a \[Rule] 0, 
      b \[Rule] 114.53368751548979`, \[CapitalDelta]b \[Rule] 
        4.517147958599848`, 
      Rsqared \[Rule] 0.9944234892175774`, \[Chi]Sqared \[Rule] 
        0.36187733198824307`, 
      sSquared \[Rule] 0.019046175367802266`}\)], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(DisplayTogether[\[IndentingNewLine]ErrorListPlot[
          dataset], \[IndentingNewLine]Plot[{b\ x + a} /. parameter // 
            Evaluate, {x, 0, Max[Column[dataset, 1]]}, 
          PlotStyle \[Rule] {Dashing[{0}]}], 
        Plot[{\((b + \[CapitalDelta]b)\) 
                    x + \((a + \[CapitalDelta]a)\), \((b - \
\[CapitalDelta]b)\) x + \((a - \[CapitalDelta]a)\)} /. parameter // 
            Evaluate, {x, 0, 
            Max[Column[dataset, 
                1]]}, \[IndentingNewLine]PlotStyle \[Rule] \
{Dashing[{0.01}]}], ImageSize \[Rule] 700, PlotLabel \[Rule] "\<dataset\>", 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
%%ImageSize: 700 432.624 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.121477 0.0147151 0.00176955 [
[.26676 .00222 -3 -9 ]
[.26676 .00222 3 0 ]
[.50972 .00222 -3 -9 ]
[.50972 .00222 3 0 ]
[.75267 .00222 -3 -9 ]
[.75267 .00222 3 0 ]
[.99563 .00222 -3 -9 ]
[.99563 .00222 3 0 ]
[1.025 .01472 0 -4.90625 ]
[1.025 .01472 10 4.90625 ]
[.01131 .10319 -12 -4.5 ]
[.01131 .10319 0 4.5 ]
[.01131 .19167 -18 -4.5 ]
[.01131 .19167 0 4.5 ]
[.01131 .28015 -18 -4.5 ]
[.01131 .28015 0 4.5 ]
[.01131 .36862 -18 -4.5 ]
[.01131 .36862 0 4.5 ]
[.01131 .4571 -18 -4.5 ]
[.01131 .4571 0 4.5 ]
[.01131 .54558 -18 -4.5 ]
[.01131 .54558 0 4.5 ]
[.02381 .64303 -5.03125 0 ]
[.02381 .64303 5.03125 9.8125 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 9.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.26676 .01472 m
.26676 .02097 L
s
[(2)] .26676 .00222 0 1 Mshowa
.50972 .01472 m
.50972 .02097 L
s
[(4)] .50972 .00222 0 1 Mshowa
.75267 .01472 m
.75267 .02097 L
s
[(6)] .75267 .00222 0 1 Mshowa
.99563 .01472 m
.99563 .02097 L
s
[(8)] .99563 .00222 0 1 Mshowa
.125 Mabswid
.08455 .01472 m
.08455 .01847 L
s
.14529 .01472 m
.14529 .01847 L
s
.20603 .01472 m
.20603 .01847 L
s
.3275 .01472 m
.3275 .01847 L
s
.38824 .01472 m
.38824 .01847 L
s
.44898 .01472 m
.44898 .01847 L
s
.57046 .01472 m
.57046 .01847 L
s
.6312 .01472 m
.6312 .01847 L
s
.69193 .01472 m
.69193 .01847 L
s
.81341 .01472 m
.81341 .01847 L
s
.87415 .01472 m
.87415 .01847 L
s
.93489 .01472 m
.93489 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .10319 m
.03006 .10319 L
s
[(50)] .01131 .10319 1 0 Mshowa
.02381 .19167 m
.03006 .19167 L
s
[(100)] .01131 .19167 1 0 Mshowa
.02381 .28015 m
.03006 .28015 L
s
[(150)] .01131 .28015 1 0 Mshowa
.02381 .36862 m
.03006 .36862 L
s
[(200)] .01131 .36862 1 0 Mshowa
.02381 .4571 m
.03006 .4571 L
s
[(250)] .01131 .4571 1 0 Mshowa
.02381 .54558 m
.03006 .54558 L
s
[(300)] .01131 .54558 1 0 Mshowa
.125 Mabswid
.02381 .03241 m
.02756 .03241 L
s
.02381 .05011 m
.02756 .05011 L
s
.02381 .0678 m
.02756 .0678 L
s
.02381 .0855 m
.02756 .0855 L
s
.02381 .12089 m
.02756 .12089 L
s
.02381 .13858 m
.02756 .13858 L
s
.02381 .15628 m
.02756 .15628 L
s
.02381 .17397 m
.02756 .17397 L
s
.02381 .20937 m
.02756 .20937 L
s
.02381 .22706 m
.02756 .22706 L
s
.02381 .24476 m
.02756 .24476 L
s
.02381 .26245 m
.02756 .26245 L
s
.02381 .29784 m
.02756 .29784 L
s
.02381 .31554 m
.02756 .31554 L
s
.02381 .33323 m
.02756 .33323 L
s
.02381 .35093 m
.02756 .35093 L
s
.02381 .38632 m
.02756 .38632 L
s
.02381 .40402 m
.02756 .40402 L
s
.02381 .42171 m
.02756 .42171 L
s
.02381 .43941 m
.02756 .43941 L
s
.02381 .4748 m
.02756 .4748 L
s
.02381 .49249 m
.02756 .49249 L
s
.02381 .51019 m
.02756 .51019 L
s
.02381 .52788 m
.02756 .52788 L
s
.02381 .56327 m
.02756 .56327 L
s
.02381 .58097 m
.02756 .58097 L
s
.02381 .59866 m
.02756 .59866 L
s
.02381 .61636 m
.02756 .61636 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.02381 .64303 -66.0312 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.062 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(dataset) show
105.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.002 w
.33479 .1593 m
.33479 .22403 L
s
.015 w
.33479 .19167 Mdot
.002 w
.36638 .17551 m
.36638 .24322 L
s
.015 w
.36638 .20937 Mdot
.002 w
.40403 .19153 m
.40403 .26259 L
s
.015 w
.40403 .22706 Mdot
.002 w
.43562 .20786 m
.43562 .28165 L
s
.015 w
.43562 .24476 Mdot
.002 w
.4672 .22419 m
.4672 .30071 L
s
.015 w
.4672 .26245 Mdot
.002 w
.49514 .24067 m
.49514 .31963 L
s
.015 w
.49514 .28015 Mdot
.002 w
.53887 .25659 m
.53887 .33909 L
s
.015 w
.53887 .29784 Mdot
.002 w
.56438 .27323 m
.56438 .35785 L
s
.015 w
.56438 .31554 Mdot
.002 w
.58017 .29022 m
.58017 .37625 L
s
.015 w
.58017 .33323 Mdot
.002 w
.61662 .30646 m
.61662 .3954 L
s
.015 w
.61662 .35093 Mdot
.002 w
.66642 .32233 m
.66642 .41492 L
s
.015 w
.66642 .36862 Mdot
.002 w
.6725 .33966 m
.6725 .43298 L
s
.015 w
.6725 .38632 Mdot
.002 w
.71137 .35587 m
.71137 .45216 L
s
.015 w
.71137 .40402 Mdot
.002 w
.7466 .37225 m
.7466 .47117 L
s
.015 w
.7466 .42171 Mdot
.002 w
.76482 .3892 m
.76482 .48961 L
s
.015 w
.76482 .43941 Mdot
.002 w
.80126 .40557 m
.80126 .50863 L
s
.015 w
.80126 .4571 Mdot
.002 w
.83285 .42212 m
.83285 .52748 L
s
.015 w
.83285 .4748 Mdot
.002 w
.85714 .43886 m
.85714 .54613 L
s
.015 w
.85714 .49249 Mdot
.002 w
.89602 .45519 m
.89602 .56519 L
s
.015 w
.89602 .51019 Mdot
.002 w
.94947 .47112 m
.94947 .58465 L
s
.015 w
.94947 .52788 Mdot
.002 w
.97619 .48784 m
.97619 .60332 L
s
.015 w
.97619 .54558 Mdot
.5 Mabswid
.02381 .01472 m
.06244 .0365 L
.10458 .06027 L
.14415 .08258 L
.18221 .10405 L
.22272 .12689 L
.26171 .14888 L
.30316 .17226 L
.34309 .19477 L
.3815 .21644 L
.42237 .23949 L
.46172 .26168 L
.49955 .28302 L
.53984 .30574 L
.57861 .3276 L
.61984 .35085 L
.65954 .37325 L
.69774 .39479 L
.73838 .41771 L
.77751 .43978 L
.81909 .46323 L
.85916 .48582 L
.89771 .50756 L
.93871 .53069 L
.97619 .55182 L
s
[ .01 ] 0 setdash
.02381 .01472 m
.06244 .03712 L
.10458 .06156 L
.14415 .08451 L
.18221 .10659 L
.22272 .13008 L
.26171 .1527 L
.30316 .17673 L
.34309 .19989 L
.3815 .22217 L
.42237 .24588 L
.46172 .2687 L
.49955 .29064 L
.53984 .31401 L
.57861 .3365 L
.61984 .36041 L
.65954 .38344 L
.69774 .40559 L
.73838 .42916 L
.77751 .45186 L
.81909 .47598 L
.85916 .49921 L
.89771 .52157 L
.93871 .54536 L
.97619 .56709 L
s
.02381 .01472 m
.06244 .03588 L
.10458 .05897 L
.14415 .08065 L
.18221 .10151 L
.22272 .1237 L
.26171 .14507 L
.30316 .16778 L
.34309 .18966 L
.3815 .2107 L
.42237 .2331 L
.46172 .25466 L
.49955 .27539 L
.53984 .29746 L
.57861 .31871 L
.61984 .3413 L
.65954 .36305 L
.69774 .38398 L
.73838 .40625 L
.77751 .42769 L
.81909 .45048 L
.85916 .47243 L
.89771 .49355 L
.93871 .51602 L
.97619 .53655 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{700, 432.625},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:l0001/2000`400?l00000o`00003oo`3ooooo
0?oookh0oooo003o0?ooool0oooo_P3oool00;d0oooo1000002K0?ooo`030000003oool0oooo09P0
oooo0P00002K0?ooo`8000009P3oool00;d0oooo00<000000?ooo`3oool0W03oool00`000000oooo
0?ooo`2G0?ooo`040000003oool0oooo000009T0oooo00@000000?ooo`3oool000009@3oool00;h0
oooo00<000000?ooo`3oool0V03oool5000009P0oooo00@000000?ooo`3oool00000V@3oool01000
0000oooo0?ooo`00000U0?ooo`00_`3oool00`000000oooo0?ooo`2G0?ooo`040000003oool0oooo
000009T0oooo0`00002K0?ooo`8000009P3oool00<00oooo00<000000?ooo`3oool0U`3oool00`00
0000oooo0000002I0?ooo`030000003oool0oooo09X0oooo00@000000?ooo`3oool000009@3oool0
02<0oooo00<000000?ooo`3oool0U`3oool010000000oooo0?ooo`00002J0?ooo`800000V@3oool0
0`000000oooo0?ooo`2J0?ooo`040000003oool0oooo000002D0oooo000S0?ooo`030000003oool0
oooo09P0oooo0P00002L0?ooo`030000003oool0oooo09P0oooo0`00002J0?ooo`8000009P3oool0
02<0oooo00<000000?ooo`3oool0o`3ooooo0?oooiP0oooo000S0?ooo`030000003oool0oooo0?l0
ooooo`3ooonH0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0ooooV03oool002<0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooiP0oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooonH
0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0ooooV03oool002<0oooo00<000000?ooo`3o
ool0o`3ooooo0?oooiP0oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooon60?ooo`800000
00<0oooo0000000000003@3oool001<0ooooo`00003o000008L000004`3oool00`000000oooo0000
000>0?ooo`008`3oool3000002@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09@3oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`000000oooo0?ooo`0T
0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0=
0?ooo`008`3oool00`000000oooo0?ooo`0200000280oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool09@3oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0903oool00`00
0000oooo0?ooo`0T0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3oool04`3oool00`00
0000oooo0000000>0?ooo`008`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo09@0
oooo00<000000?ooo`3oool0VP3oool00`000000oooo0?ooo`2I0?ooo`030000003oool0oooo09X0
oooo00<000000?ooo`3oool04P3oool2000000030?ooo`000000000000d0oooo000S0?ooo`030000
003oool0oooo00<0oooo0P00002D0?ooo`030000003oool0oooo09X0oooo00<000000?ooo`3oool0
V@3oool00`000000oooo0?ooo`2J0?ooo`030000003oool0oooo02@0oooo000S0?ooo`030000003o
ool0oooo00D0oooo0P00003o0?ooool0ooooT@3oool002<0oooo00<000000?ooo`3oool01`3oool2
00000?l0ooooo`3ooon?0?ooo`008`3oool00`000000oooo0?ooo`090?ooo`800000o`3ooooo0?oo
ohd0oooo000S0?ooo`030000003oool0oooo00X0oooo0`00003o0?ooool0ooooR`3oool002<0oooo
00<000000?ooo`3oool0303oool200000?l0ooooo`3ooon:0?ooo`008`3oool00`000000oooo0?oo
o`0=0?ooo`800000o`3ooooo0?ooohT0oooo000S0?ooo`<000003`3oool200000?l0ooooo`3ooon7
0?ooo`008`3oool00`000000oooo0?ooo`0A0?ooo`<00000o`3ooooo0?oooh@0oooo000S0?ooo`03
0000003oool0oooo01<0oooo0P00003o0?ooool0ooooP`3oool002<0oooo00<000000?ooo`3oool0
503oool300000?l0ooooo`3ooon10?ooo`008`3oool00`000000oooo0?ooo`0F0?ooo`@00000o`3o
oooo0?ooogh0oooo000S0?ooo`030000003oool0oooo01P0oooo0P00003o0?ooool0ooooOP3oool0
02<0oooo00<000000?ooo`3oool06P3oool200000?l0ooooo`3oooml0?ooo`008`3oool00`000000
oooo0?ooo`0L0?ooo`<00000o`3ooooo0?ooogT0oooo000S0?ooo`030000003oool0oooo01h0oooo
0`00003o0?ooool0ooooM`3oool002<0oooo00<000000?ooo`3oool07`3oool300000?l0ooooo`3o
oomf0?ooo`008`3oool00`000000oooo0?ooo`0Q0?ooo`<00000o`3ooooo0?ooog@0oooo000S0?oo
o`030000003oool0oooo0280oooo0`00003o0?ooool0ooooL`3oool002<0oooo0`00000T0?ooo`<0
0000o`3ooooo0?ooog40oooo000S0?ooo`030000003oool0oooo02L0oooo0P00003o0?ooool0oooo
K`3oool002<0oooo00<000000?ooo`3oool0:@3oool200000?l0ooooo`3ooom]0?ooo`008`3oool0
0`000000oooo0?ooo`0Y0?ooo`040000003oool0000000000?l0ooooo`3ooom[0?ooo`008`3oool0
0`000000oooo0?ooo`0Z0?ooo`80000000<0oooo000000000000o`3ooooo0?ooofT0oooo000S0?oo
o`030000003oool0oooo02`0oooo0P0000000`3oool000000000003o0?ooool0ooooI`3oool002<0
oooo00<000000?ooo`3oool0;P3oool2000000030?ooo`000000oooo0?l0ooooo`3ooomU0?ooo`00
8`3oool00`000000oooo0?ooo`0b0?ooo`800000o`3ooooo0?ooof@0oooo000S0?ooo`030000003o
ool0oooo03@0oooo0P00003o0?ooool0ooooHP3oool002<0oooo00<000000?ooo`3oool0=03oool0
10000000oooo00000000003o0?ooool0ooooH03oool002<0oooo00<000000?ooo`3oool0=@3oool5
00000?l0ooooo`3ooomN0?ooo`008`3oool3000003L0oooo1@00003o0?ooool0ooooG03oool002<0
oooo00<000000?ooo`3oool0>@3oool300000?l0ooooo`3ooomL0?ooo`008`3oool00`000000oooo
0?ooo`0l0?ooo`800000o`3ooooo0?oooeX0oooo000S0?ooo`030000003oool0oooo03h0oooo0`00
003o0?ooool0ooooE`3oool002<0oooo00<000000?ooo`3oool0@03oool300000?l0ooooo`3ooomE
0?ooo`008`3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0000000<00000o`3ooooo0?oo
oe<0oooo000S0?ooo`030000003oool0oooo0400oooo0P0000000`3oool000000000000200000?l0
ooooo`3ooomA0?ooo`008`3oool00`000000oooo0?ooo`120?ooo`80000000<0oooo0000003oool0
o`3ooooo0?oooe40oooo000S0?ooo`030000003oool0oooo04@0oooo1000003o0?ooool0ooooD03o
ool002<0oooo00<000000?ooo`3oool0B03oool200000080oooo00<000000?ooo`3oool0o`3ooooo
0?ooodT0oooo000S0?ooo`030000003oool0oooo04X0oooo00<000000?ooo`3oool00P00003o0?oo
ool0ooooB@3oool002<0oooo00<000000?ooo`3oool0B`3oool200000080oooo0P00003o0?ooool0
ooooA`3oool002<0oooo0`00001<0?ooo`<000000P3oool00`000000oooo0?ooo`3o0?ooool0oooo
A03oool002<0oooo00<000000?ooo`3oool0CP3oool300000?l0ooooo`3ooom70?ooo`008`3oool0
0`000000oooo0?ooo`1@0?ooo`<00000o`3ooooo0?ooodD0oooo000S0?ooo`030000003oool0oooo
05<0oooo0P0000020?ooo`030000003oool0oooo0?l0ooooo`3oooln0?ooo`008`3oool00`000000
oooo0?ooo`1E0?ooo`80000000<0oooo000000000000o`3ooooo0?oooch0oooo000S0?ooo`030000
003oool0oooo05L0oooo0P0000000`3oool000000?ooo`3o0?ooool0oooo?03oool002<0oooo00<0
00000?ooo`3oool0EP3oool00`000000oooo0?ooo`0400000?l0ooooo`3ooolk0?ooo`008`3oool0
0`000000oooo0?ooo`1G0?ooo`8000000P3oool300000?l0ooooo`3ooolj0?ooo`008`3oool00`00
0000oooo0?ooo`1I0?ooo`8000000P3oool200000?l0ooooo`3oooli0?ooo`003`3oool3000000@0
oooo0P00000;0?ooo`030000003oool0oooo05/0oooo00@000000?ooo`3oool0oooo0P00003o0?oo
ool0oooo=`3oool00180oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0640oooo0`00003o0?ooool0oooo=03oool00180oooo00@000000?ooo`3o
ool000000P3oool00`000000oooo0?ooo`080?ooo`D00000H@3oool300000?l0ooooo`3ooolb0?oo
o`003`3oool3000000<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`1Q0?oo
o`030000003oool0oooo00@00000o`3ooooo0?oooc00oooo000?0?ooo`030000003oool0oooo00<0
oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`1R0?ooo`8000000P3oool30000
0?l0ooooo`3oool_0?ooo`003`3oool00`000000oooo0?ooo`030?ooo`040000003oool0oooo0000
00X0oooo00<000000?ooo`3oool0I03oool200000080oooo0P00003o0?ooool0oooo;P3oool000l0
oooo100000030?ooo`8000002`3oool00`000000oooo0?ooo`1V0?ooo`050000003oool0oooo0?oo
o`000000o`3ooooo0?ooobd0oooo000S0?ooo`030000003oool0oooo06/0oooo0`00003o0?ooool0
oooo:P3oool002<0oooo00<000000?ooo`3oool0K@3oool300000?l0ooooo`3ooolX0?ooo`008`3o
ool00`000000oooo0?ooo`1_0?ooo`<00000o`3ooooo0?ooobH0oooo000S0?ooo`030000003oool0
oooo06`0oooo00@000000?ooo`3oool0oooo1000003o0?ooool0oooo903oool002<0oooo00<00000
0?ooo`3oool0K@3oool2000000<0oooo0P00003o0?ooool0oooo903oool002<0oooo00<000000?oo
o`3oool0K`3oool2000000<0oooo0P00003o0?ooool0oooo8P3oool002<0oooo0`00001a0?ooo`80
00000`3oool010000000oooo0?ooo`00003o0?ooool0oooo7P3oool002<0oooo00<000000?ooo`3o
ool0M`3oool2000000030?ooo`00000000000?l0ooooo`3ooolL0?ooo`008`3oool00`000000oooo
0?ooo`1i0?ooo`80000000<0oooo000000000000o`3ooooo0?oooaX0oooo000S0?ooo`030000003o
ool0oooo07L0oooo00@000000?ooo`3oool0oooo0P0000000`3oool000000?ooo`3o0?ooool0oooo
603oool002<0oooo00<000000?ooo`3oool0N03oool2000000<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaP0oooo000S0?ooo`030000003oool0oooo07X0oooo0P0000020?ooo`800000o`3ooooo
0?oooaP0oooo000S0?ooo`030000003oool0oooo07`0oooo0P0000020?ooo`8000000P3oool00`00
0000oooo0?ooo`3o0?ooool0oooo4@3oool002<0oooo00<000000?ooo`3oool0PP3oool200000003
0?ooo`00000000000?l0ooooo`3ooolA0?ooo`008`3oool00`000000oooo0?ooo`240?ooo`800000
00<0oooo000000000000o`3ooooo0?ooo`l0oooo000S0?ooo`030000003oool0oooo08H0oooo00<0
00000?ooo`3oool00P00003o0?ooool0oooo3@3oool002<0oooo00<000000?ooo`3oool0PP3oool0
0`000000oooo0?ooo`020?ooo`800000o`3ooooo0?ooo`l0oooo000S0?ooo`030000003oool0oooo
08<0oooo0P0000040?ooo`800000o`3ooooo0?ooo`d0oooo000S0?ooo`<00000Q@3oool2000000@0
oooo0P0000020?ooo`030000003oool0oooo0?l0ooooo`3oool60?ooo`008`3oool00`000000oooo
0?ooo`270?ooo`800000103oool00`000000oooo0?ooo`0200000?l0ooooo`3oool60?ooo`008`3o
ool00`000000oooo0?ooo`2>0?ooo`8000000P3oool00`000000oooo0?ooo`3o0?ooool0oooo0`3o
ool002<0oooo00<000000?ooo`3oool0T03oool2000000030?ooo`00000000000?l0ooooo`3oool3
0?ooo`008`3oool00`000000oooo0?ooo`2=0?ooo`030000003oool0oooo0080oooo0P0000000`3o
ool000000?ooo`3o0?ooool0oooo0@3oool002<0oooo00<000000?ooo`3oool0SP3oool2000000@0
oooo0P00003o0?ooool0oooo0P3oool002<0oooo00<000000?ooo`3oool0T03oool2000000@0oooo
00<000000?ooo`3oool0o`3oooon0?ooo`008`3oool00`000000oooo0?ooo`2B0?ooo`8000000`3o
ool200000080oooo00<000000?ooo`3oool0o`3ooooi0?ooo`008`3oool00`000000oooo0?ooo`2I
0?ooo`80000000<0oooo000000000000o`3ooooi0?ooo`008`3oool00`000000oooo0?ooo`2K0?oo
o`80000000<0oooo000000000000o`3oooog0?ooo`008`3oool00`000000oooo0?ooo`2I0?ooo`04
0000003oool0oooo0?ooo`80000000<0oooo0000003oool0o`3ooooe0?ooo`008`3oool3000009X0
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`3o0?ooooD0oooo000S0?ooo`030000
003oool0oooo09/0oooo0P0000030?ooo`800000o`3ooooe0?ooo`008`3oool00`000000oooo0?oo
o`2M0?ooo`030000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo01`0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`008`3oool00`000000oooo0?ooo`2N0?ooo`030000003oool0
oooo00<0oooo0P0000000`3oool000000000000L0?ooo`030000003oool0oooo0?l0ooooc`3oool0
02<0oooo00<000000?ooo`3oool0YP3oool2000000030?ooo`000000000001X0oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`008`3oool00`000000oooo0?ooo`2X0?ooo`030000003oool0oooo0080
0000603oool00`000000oooo0?ooo`3o0?oooll0oooo000S0?ooo`030000003oool0oooo0:@0oooo
00<000000?ooo`3oool00P3oool2000001X0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`008`3o
ool00`000000oooo0?ooo`2U0?ooo`800000103oool2000001P0oooo00<000000?ooo`3oool0o`3o
ooo?0?ooo`008`3oool00`000000oooo0?ooo`2W0?ooo`800000103oool200000080oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oooll0oooo000S0?ooo`030000003oool0oooo
0:T0oooo00<000000?ooo`3oool00`3oool2000000030?ooo`00000000000140oooo00<000000?oo
o`3oool0o`3oooo?0?ooo`008`3oool00`000000oooo0?ooo`2a0?ooo`030000003oool0oooo0080
00003`3oool00`000000oooo0?ooo`3o0?oooll0oooo000S0?ooo`030000003oool0oooo0;80oooo
0P0000020?ooo`8000003@3oool00`000000oooo0?ooo`3o0?oooll0oooo000S0?ooo`<00000[`3o
ool00`000000oooo0?ooo`020?ooo`8000003`3oool00`000000oooo0?ooo`3o0?oooll0oooo000S
0?ooo`030000003oool0oooo0;00oooo0P0000040?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?oook/0oooo000S0?ooo`030000003oool0oooo
0;80oooo00<000000?ooo`3oool00P3oool2000000@0oooo00<000000?ooo`3oool01@3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo^`3oool002<0oooo00<000000?ooo`3o
ool0/`3oool00`000000oooo0?ooo`030?ooo`8000000`3oool2000000D0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`3o0?oook/0oooo000S0?ooo`030000003oool0oooo0;@0oooo
00<000000?ooo`3oool0103oool00`000000oooo0?ooo`020?ooo`8000000`3oool00`000000oooo
0?ooo`0A0?ooo`030000003oool0oooo0?l0oooo^`3oool002<0oooo00<000000?ooo`3oool0_03o
ool2000000@0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?ooo`3o0?oook/0oooo
000S0?ooo`030000003oool0oooo0;h0oooo0P0000050?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0o`3ooonk0?ooo`008`3oool00`000000oooo0?ooo`2j0?ooo`030000003oool0
oooo00<0oooo00<000000?ooo`3oool01P00000@0?ooo`030000003oool0oooo0?l0oooo^`3oool0
02<0oooo00<000000?ooo`3oool0^`3oool2000000@0oooo2@00000?0?ooo`030000003oool0oooo
0?l0oooo^`3oool000T0oooo100000030?ooo`800000103oool2000000/0oooo00<000000?ooo`3o
ool0_@3oool2000000<0oooo2000000?0?ooo`030000003oool0oooo0?l0oooo^`3oool000/0oooo
00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`2o0?ooo`80000000<0oooo0000000000002000000=0?oo
o`030000003oool0oooo0?l0oooo^`3oool000/0oooo00D000000?ooo`3oool0oooo000000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool500000<00oooo20000002
0?ooo`<000002P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooX`3oool0
00/0oooo00D000000?ooo`3oool0oooo000000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool0203oool00`000000oooo0?ooo`320?ooo`P000003`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0?l0ooooX`3oool000/0oooo00D000000?ooo`3oool0oooo0000
00020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`320?ooo`T000003P3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0oooo
X`3oool000T0oooo0`0000030?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool0
00002P3oool00`000000oooo0?ooo`330?ooo`H000000P3oool2000000`0oooo00<000000?ooo`3o
ool05@3oool00`000000oooo0?ooo`3o0?oooj<0oooo000;0?ooo`030000003oool0oooo0080oooo
0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`350?ooo`030000003oool0oooo00800000
0`3oool2000000@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0E0?ooo`030000
003oool0oooo0?l0ooooX`3oool002<0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?oo
o`020?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000000`3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0?l0ooooX`3oool002<0oooo00<000000?ooo`3oool0a@3oool0
0`000000oooo0?ooo`030?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`80000000<0oooo
0000003oool05P3oool00`000000oooo0?ooo`3o0?oooj<0oooo000S0?ooo`030000003oool0oooo
0<D0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`020?ooo`8000005`3oool00`00
0000oooo0?ooo`3o0?oooj<0oooo000S0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3o
ool0303oool2000000030?ooo`000000000000@00000503oool00`000000oooo0?ooo`3o0?oooj<0
oooo000S0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3oool0203oool00`000000oooo
0?ooo`030?ooo`P000004`3oool00`000000oooo0?ooo`3o0?oooj<0oooo000S0?ooo`030000003o
ool0oooo0<D0oooo00<000000?ooo`3oool02@3oool2000000<0oooo2P00000A0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0o`3ooon>0?ooo`008`3oool300000<D0oooo00<00000
0?ooo`3oool02`3oool2000000030?ooo`000000000000H000000P3oool2000000l0oooo00<00000
0?ooo`3oool04P3oool00`000000oooo0?ooo`3o0?ooohh0oooo000S0?ooo`030000003oool0oooo
0<D0oooo00<000000?ooo`3oool03@3oool9000000@0oooo0P00000=0?ooo`030000003oool0oooo
0180oooo00<000000?ooo`3oool0o`3ooon>0?ooo`008`3oool00`000000oooo0?ooo`350?ooo`03
0000003oool0oooo00h0oooo2@0000050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`3o0?ooohh0oooo000S0?ooo`030000003oool0oooo0<D0oooo
00<000000?ooo`3oool03P3oool8000000030?ooo`00000000000100oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`3o0?ooohh0oooo000S0?ooo`030000003oool0oooo0<D0oooo00<0
00000?ooo`3oool03`3oool6000000@0oooo0P00000>0?ooo`030000003oool0oooo0180oooo00<0
00000?ooo`3oool0o`3ooon>0?ooo`008`3oool00`000000oooo0?ooo`350?ooo`030000003oool0
oooo0140oooo00<000000?ooo`3oool00P0000050?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0103oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo0?l0ooooSP3oool0
02<0oooo00<000000?ooo`3oool0a@3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0080oooo0P0000040?ooo`8000001@3oool2000000@0oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`3o0?ooohh0oooo000S0?ooo`030000003oool0oooo0<D0oooo00<000000?ooo`3o
ool04@3oool00`000000oooo0?ooo`040?ooo`800000103oool2000000D0oooo0P0000020?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0o`3ooon>0?ooo`008`3oool00`000000oooo
0?ooo`350?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0303oool2000000D0oooo
1P00000A0?ooo`030000003oool0oooo0?l0ooooSP3oool002<0oooo00<000000?ooo`3oool0a@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00h0oooo00@000000?ooo`3oool0oooo
2000000@0?ooo`030000003oool0oooo0?l0ooooSP3oool002<0oooo00<000000?ooo`3oool0a@3o
ool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00l0oooo0P0000000`3oool000000000
000600000100oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`3o0?ooogX0oooo000S
0?ooo`030000003oool0oooo0=T0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`T00000403oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool0
02<0oooo0`00003I0?ooo`030000003oool0oooo00`0oooo0P0000040?ooo`X000003P3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool002<0oooo00<000000?ooo`3o
ool0f@3oool00`000000oooo0?ooo`0>0?ooo`8000000P3oool800000080oooo0P00000<0?ooo`03
0000003oool0oooo0140oooo00<000000?ooo`3oool0o`3ooomj0?ooo`008`3oool00`000000oooo
0?ooo`3I0?ooo`030000003oool0oooo0100oooo00<000000?ooo`0000001`0000040?ooo`800000
2P3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool002<0oooo00<0
00000?ooo`3oool0f@3oool00`000000oooo0?ooo`0C0?ooo`L00000403oool00`000000oooo0?oo
o`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool002<0oooo00<000000?ooo`3oool0f@3oool0
0`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool03@3oool0
0`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool002<0oooo00<000000?oo
o`3oool0f@3oool00`000000oooo0?ooo`0E0?ooo`800000103oool2000000L0oooo00<000000?oo
o`3oool00`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo0?l0ooooNP3oool002<0
oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0E0?ooo`040000003oool000000000
00@0oooo0P0000060?ooo`8000000`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo
0?l0ooooNP3oool002<0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0E0?ooo`04
0000003oool0oooo0?ooo`800000103oool2000000H0oooo1`00000@0?ooo`030000003oool0oooo
0?l0ooooNP3oool002<0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo00<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`030?ooo`P0
00003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooJ03oool002<0oooo
00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo00X0oooo
0P0000030?ooo`P000003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0oooo
J03oool002<0oooo00<000000?ooo`3oool0f@3oool00`000000oooo0?ooo`0E0?ooo`030000003o
ool0oooo00`0oooo0P0000000`3oool0000000000006000000l0oooo00<000000?ooo`3oool03`3o
ool00`000000oooo0?ooo`3o0?ooofP0oooo000S0?ooo`<00000l@3oool00`000000oooo0?ooo`0>
0?ooo`T000003`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooJ03oool0
02<0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo
00<0oooo200000000`3oool000000?ooo`0<0?ooo`030000003oool0oooo00l0oooo00<000000?oo
o`3oool0o`3ooomX0?ooo`008`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo00X0
oooo0P0000030?ooo`P000000P3oool2000000/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`3o0?ooofP0oooo000S0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool0
303oool200000080oooo1P0000050?ooo`8000002@3oool00`000000oooo0?ooo`0?0?ooo`030000
003oool0oooo0?l0ooooJ03oool002<0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?oo
o`0>0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00H0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`3o0?ooofP0oooo
000S0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`020?ooo`8000003@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo0?l0ooooJ03o
ool002<0oooo00<000000?ooo`3oool0l@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0
oooo00@0oooo0P00000;0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0o`3ooomX
0?ooo`008`3oool00`000000oooo0?ooo`3a0?ooo`030000003oool0oooo0180oooo00<000000?oo
o`0000001P3oool2000000H0oooo00@000000?ooo`3oool000004@3oool00`000000oooo0?ooo`3o
0?ooofP0oooo000S0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool04P3oool00`00
0000oooo0?ooo`02000000H0oooo0P0000050?ooo`H000003P3oool00`000000oooo0?ooo`0I0?oo
o`030000003oool0oooo0?l0ooooC03oool002<0oooo00<000000?ooo`3oool0l@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo0080oooo0P0000060?ooo`8000000P3oool8000000d0
oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oood`0oooo000S0?ooo`030000
003oool0oooo0?40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`040?ooo`800000
1P3oool:000000d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oood`0oooo
000S0?ooo`030000003oool0oooo0?40oooo00<000000?ooo`3oool04P3oool00`000000oooo0?oo
o`0>0?ooo`P000003@3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooC03o
ool002<0oooo0`00003a0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool03P3oool8
000000d0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`3o0?oood`0oooo000S0?oo
o`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`0>0?ooo`P000000`3oool00`00
0000oooo0?ooo`070?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0o`3ooom<0?oo
o`008`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool02P3oool010000000
oooo0?ooo`3oool8000000@0oooo0P0000070?ooo`030000003oool0oooo01T0oooo00<000000?oo
o`3oool0o`3ooom<0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3o
ool02`3oool200000080oooo1`0000060?ooo`8000001@3oool00`000000oooo0?ooo`0I0?ooo`03
0000003oool0oooo0?l0ooooC03oool002<0oooo00<000000?ooo`3oool0o`3oool70?ooo`030000
003oool0oooo00d0oooo0P0000020?ooo`030000003oool0oooo0080oooo0P0000060?ooo`800000
0`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooC03oool002<0oooo00<0
00000?ooo`3oool0o`3oool70?ooo`030000003oool0oooo00l0oooo0`0000060?ooo`8000002@3o
ool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo0?l0ooooC03oool002<0oooo00<00000
0?ooo`3oool0o`3oool70?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`3o0?oooc/0oooo000S0?ooo`030000003oool0oooo0?l0oooo1`3oool00`00
0000oooo0?ooo`0A0?ooo`030000003oool0oooo00L0oooo0P0000040?ooo`H00000603oool00`00
0000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo>`3oool002<0oooo00<000000?ooo`3o
ool0o`3oool70?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo000000070?oo
o`80000000<0oooo0000000000001P00000G0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0o`3ooolk0?ooo`002@3oool400000080oooo0`0000040?ooo`8000002`3oool00`000000
oooo0?ooo`3o0?ooo`L0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`020?ooo`80
00001`3oool:000001H0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oooc/0
oooo000;0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo1`3oool00`000000oooo0?ooo`0A0?ooo`03
0000003oool0oooo00@0oooo0P0000060?ooo`P0000000<0oooo000000000000503oool00`000000
oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo>`3oool000/0oooo00<000000?ooo`3oool0
103oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00P0oooo1@00003o0?ooo`D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`060?ooo`800000103oool8000001L0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`3o0?oooc/0oooo000;0?ooo`040000
003oool0oooo0?ooo`<000000`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo
0?l0oooo1`3oool00`000000oooo0?ooo`0A0?ooo`030000003oool0oooo00`0oooo2000000G0?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`002`3oool01@000000
oooo0?ooo`3oool0000000D0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o
0?oooa/0oooo00<000000?ooo`3oool0303oool8000000P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0?l0oooo>`3oool000T0oooo0`0000030?oo
o`030000003oool0oooo00<0oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o
0?oooa/0oooo00<000000?ooo`3oool0303oool9000000P0oooo0P00000<0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0o`3ooolk0?ooo`002`3oool010000000oooo0?ooo`3oool4
000000<0oooo0P00000;0?ooo`030000003oool0oooo0?l0oooo6`3oool00`000000oooo0?ooo`0=
0?ooo`<000001@3oool2000000P0oooo0P00000:0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0o`3ooolk0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?oo
o`3oool03`3oool00`000000oooo0?ooo`050?ooo`800000203oool2000000P0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`3o0?oooc/0oooo000S0?ooo`030000003oool0oooo0?l0
oooo6`3oool00`000000oooo0?ooo`0?0?ooo`<000001`3oool200000100oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo<@3oool002<0oooo
00<000000?ooo`3oool0o`3ooolK0?ooo`030000003oool0oooo00l0oooo00@000000?ooo`3oool0
0000203oool2000000h0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`070?ooo`03
0000003oool0oooo0?l0oooo<@3oool002<0oooo00<000000?ooo`3oool0o`3ooolK0?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool02`3oool2000000P0oooo00<000000?ooo`000000
1@00000=0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooola0?ooo`008`3o
ool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo00H0oooo2000000<0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0o`3ooola0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<00000
0?ooo`3oool03`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo0P000006
0?ooo`P00000303oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0?l0oooo<@3oool0
02<0oooo0`00003o0?oooa/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`070?oo
o`8000001`3oool2000000@0oooo2000000<0?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0o`3ooola0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooa/0oooo00<000000?ooo`3o
ool03`3oool00`000000oooo0?ooo`090?ooo`8000001`3oool200000080oooo2000000<0?ooo`03
0000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooola0?ooo`008`3oool00`000000oooo
0?ooo`3o0?oooa/0oooo00<000000?ooo`3oool03`3oool00`000000oooo0?ooo`0;0?ooo`030000
003oool0oooo00H0oooo2P00000<0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
o`3ooola0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool05P3o
ool8000000`0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?oooc40oooo000S
0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0G0?ooo`H000000`3oool0
0`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooola
0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool04@3oool00`00
0000oooo0?ooo`050?ooo`8000001P3oool2000000L0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`3o0?oooc40oooo000S0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000
oooo0?ooo`0B0?ooo`030000003oool0oooo00@0oooo00@000000?ooo`00000000001P3oool20000
00D0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo
0?l0oooo6P3oool002<0oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo01<0
oooo0P0000040?ooo`040000003oool0oooo0?ooo`8000001P3oool2000000<0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo6P3oool002<0
oooo00<000000?ooo`3oool0o`3oool]0?ooo`030000003oool0oooo01D0oooo00D000000?ooo`3o
ool0oooo000000050?ooo`8000001P3oool6000000L0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`3o0?oooaX0oooo000S0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000
oooo0?ooo`0F0?ooo`040000003oool0oooo000000L0oooo0P0000030?ooo`P000001P3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0?l0oooo6P3oool002<0oooo00<000000?ooo`3o
ool0o`3oool]0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool01`3oool00`000000
oooo0?ooo`08000000H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oooaX0
oooo000S0?ooo`030000003oool0oooo0?l0oooo;@3oool00`000000oooo0?ooo`0I0?ooo`030000
003oool0oooo00P0oooo2`0000050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
o`3ooolJ0?ooo`008`3oool300000?l0oooo;@3oool00`000000oooo0?ooo`0I0?ooo`040000003o
ool0oooo000000T0oooo200000000`3oool00000000000030?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0o`3ooolJ0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooobd0oooo00<0
00000?ooo`3oool06@3oool010000000oooo0?ooo`3oool2000000L0oooo200000030?ooo`040000
003oool0oooo000001H0oooo00<000000?ooo`3oool0o`3ooolJ0?ooo`008`3oool00`000000oooo
0?ooo`3o0?ooobd0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`030?ooo`800000
1@3oool8000000H0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`3o0?oooaX0oooo
000S0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo00<0oooo1P0000070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0o`3o
oolJ0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooodT0oooo00<000000?ooo`3oool03P3oool0
0`000000oooo0?ooo`02000000D0oooo00@000000?ooo`3oool000004`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0?P0oooo000S0?ooo`030000003oool0oooo0?l0ooooB@3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`040000003oool0
oooo0?ooo`8000004@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?P0oooo000S
0?ooo`030000003oool0oooo0?l0ooooB@3oool00`000000oooo0?ooo`0;0?ooo`040000003oool0
oooo000000H0oooo0P0000000`3oool000000?ooo`040?ooo`8000003`3oool00`000000oooo0?oo
o`0N0?ooo`030000003oool0oooo0?P0oooo000S0?ooo`030000003oool0oooo0?l0ooooB@3oool0
0`000000oooo0?ooo`0<0?ooo`<000001`3oool6000000@0oooo0P00000=0?ooo`030000003oool0
oooo01h0oooo00<000000?ooo`3oool0n03oool002<0oooo00<000000?ooo`3oool0o`3ooom90?oo
o`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool800000180oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooodT0
oooo00<000000?ooo`3oool03P3oool3000000@0oooo2000000B0?ooo`030000003oool0oooo01h0
oooo00<000000?ooo`3oool0n03oool002<0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000
003oool0oooo00h0oooo00@000000?ooo`3oool000000`3oool9000000P0oooo00<000000?ooo`3o
ool01P3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo0?P0oooo000S0?ooo`<00000
o`3ooom90?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0103oool8000000030?oo
o`000000000000L0oooo0P0000060?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0
n03oool002<0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00h0oooo00<0
00000?ooo`3oool0103oool8000000<0oooo00<000000?ooo`3oool01P3oool2000000@0oooo00<0
00000?ooo`3oool07P3oool00`000000oooo0?ooo`3h0?ooo`008`3oool00`000000oooo0?ooo`3o
0?ooodT0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`P00000103oool2
000000P0oooo0P0000020?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3oool0n03oool0
02<0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool01@3oool6000000L0oooo0P00000:0?ooo`030000003oool0oooo01h0oooo00<000000?oo
o`3oool0n03oool002<0oooo00<000000?ooo`3oool0o`3ooom90?ooo`030000003oool0oooo00h0
oooo00<000000?ooo`3oool01`3oool010000000oooo0000000000090?ooo`800000203oool00`00
0000oooo0?ooo`0N0?ooo`040000003oool0oooo00000?L0oooo000S0?ooo`030000003oool0oooo
0?l0ooooFP3oool00`000000oooo0?ooo`070?ooo`050000003oool0oooo0?ooo`0000002P3oool2
000000H0oooo00@000000?ooo`3oool000007@3oool010000000oooo0?ooo`00003g0?ooo`008`3o
ool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo00<0oooo00D000000?ooo`3oool0oooo0000000L0?ooo`040000
003oool0oooo00000?L0oooo000S0?ooo`030000003oool0oooo0?l0ooooFP3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00l0oooo0P0000030?ooo`030000003oool0oooo0080oooo
0P00000J0?ooo`040000003oool0oooo00000?L0oooo000S0?ooo`030000003oool0oooo0?l0oooo
FP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0
203oool7000000<0oooo00<000000?ooo`3oool05`3oool010000000oooo0?ooo`00003g0?ooo`00
8`3oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`070?ooo`800000203oool8000000<0oooo00<000000?ooo`3oool05P3oool010000000oooo
0?ooo`00003g0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`090?ooo`8000001P3oool8000001`0oooo00@000000?ooo`3oool0
0000m`3oool002<0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool02`3oool2000000@0oooo2000000L0?ooo`040000003oool0oooo00000?L0
oooo000S0?ooo`<00000o`3ooomJ0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
4@3oool9000000P0oooo00<000000?ooo`3oool0403oool010000000oooo0?ooo`00003g0?ooo`00
8`3oool00`000000oooo0?ooo`3o0?oooeX0oooo00<000000?ooo`3oool01`3oool00`000000oooo
0?ooo`0A0?ooo`P0000000<0oooo0000000000001`3oool200000100oooo00@000000?ooo`3oool0
0000m`3oool002<0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000003oool0oooo00L0oooo
00<000000?ooo`3oool04@3oool8000000<0oooo00<000000?ooo`3oool01P3oool2000000h0oooo
00@000000?ooo`3oool00000m`3oool002<0oooo00<000000?ooo`3oool0o`3ooomJ0?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool04@3oool7000000D0oooo0P0000080?ooo`800000
303oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0=`0oooo000S0?ooo`030000
003oool0oooo0?l0ooooFP3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo0180oooo
0`00000:0?ooo`800000503oool010000000oooo0?ooo`00000H0?ooo`030000003oool0oooo0=`0
oooo000S0?ooo`030000003oool0oooo0?l0ooooI03oool00`000000oooo0?ooo`0D0?ooo`800000
2`3oool00`000000oooo0?ooo`0A0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3o
ool0g03oool002<0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo01@0oooo
00@000000?ooo`00000000002P3oool2000000T0oooo0P0000060?ooo`040000003oool0oooo0000
01P0oooo00<000000?ooo`3oool0g03oool002<0oooo00<000000?ooo`3oool0o`3ooomT0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool03@3oool2000000T0oooo0P0000000`3oool0
000000000005000001P0oooo00<000000?ooo`3oool0g03oool002<0oooo00<000000?ooo`3oool0
o`3ooomT0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`080?ooo`P00000603oool00`000000oooo0?ooo`3L0?ooo`002@3oool4000000<0oooo0P00
00040?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00L0oooo0P0000080?ooo`P00000603o
ool00`000000oooo0?ooo`3L0?ooo`002@3oool00`000000oooo0?ooo`030?ooo`040000003oool0
oooo00000080oooo00@000000?ooo`3oool000002P3oool00`000000oooo0?ooo`3o0?ooof@0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`070?ooo`8000002@3oool2000000H0oooo
2000000H0?ooo`030000003oool0oooo0=`0oooo000:0?ooo`030000003oool0oooo0080oooo00@0
00000?ooo`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`D00000o`3ooomR0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool2000000T0oooo00<000000?ooo`3o
ool00`3oool8000001P0oooo00<000000?ooo`3oool0g03oool000/0oooo00D000000?ooo`3oool0
oooo000000020?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool00`00
0000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0;0?oo
o`030000003oool0oooo00L0oooo0P0000030?ooo`T000005`3oool00`000000oooo0?ooo`3L0?oo
o`00303oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooof@0oooo00<000000?ooo`3oool0503oool0
0`000000oooo0?ooo`0G0?ooo`80000000<0oooo0000000000001P0000000`3oool000000000000E
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0a@3oool000T0oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
6@3oool00`000000oooo00000006000000<0oooo0P00000C0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0a@3oool000X0oooo0P0000040?ooo`800000103oool2000000/0oooo00<0
00000?ooo`3oool0o`3ooomT0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool06P3o
ool200000080oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`0@0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool0a@3oool002<0oooo00<000000?ooo`3oool0o`3o
oomT0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?oo
o`080?ooo`<000000P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0a@3oool002<0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`030000003oool0
oooo0180oooo0P00000:0?ooo`80000000<0oooo0000003oool05`3oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo0<D0oooo000S0?ooo`030000003oool0oooo0?l0ooooN`3oool00`00
0000oooo0?ooo`0D0?ooo`800000203oool010000000oooo00000000000;0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`350?ooo`008`3oool00`00
0000oooo0?ooo`3o0?ooog/0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`050?oo
o`L000002@3oool2000000X0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`350?oo
o`008`3oool00`000000oooo0?ooo`3o0?ooog/0oooo00<000000?ooo`3oool07P3oool8000000X0
oooo0P0000080?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0a@3oool002<0oooo
00<000000?ooo`3oool0o`3ooomk0?ooo`030000003oool0oooo01h0oooo2@00000;0?ooo`800000
1P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0<D0oooo000S0?ooo`<00000o`3o
oomk0?ooo`030000003oool0oooo01`0oooo00<000000?ooo`0000001`0000000`3oool000000000
000A0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0a@3oool002<0oooo00<00000
0?ooo`3oool0o`3ooomk0?ooo`030000003oool0oooo01d0oooo2@0000030?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`350?ooo`008`3oool00`00
0000oooo0?ooo`3o0?ooog/0oooo00<000000?ooo`3oool07P3oool8000000@0oooo0P00000<0?oo
o`030000003oool0000001H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`2i0?oo
o`008`3oool00`000000oooo0?ooo`3o0?ooog/0oooo00<000000?ooo`3oool07P3oool8000000H0
oooo0P00000;0?ooo`8000005P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0;T0
oooo000S0?ooo`030000003oool0oooo0?l0ooooN`3oool00`000000oooo0?ooo`0N0?ooo`L00000
2@3oool2000000X0oooo0`00000D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
^@3oool002<0oooo00<000000?ooo`3oool0o`3ooomk0?ooo`030000003oool0oooo01h0oooo00@0
00000?ooo`3oool000003P3oool2000000P0oooo00<000000?ooo`3oool00P00000B0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0^@3oool002<0oooo00<000000?ooo`3oool0o`3o
oomk0?ooo`030000003oool0oooo01h0oooo00@000000?ooo`3oool00000403oool00`000000oooo
0?ooo`050?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2i0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooi`0oooo00@000000?ooo`3oool00000
1@3oool00`000000oooo0?ooo`090?ooo`8000001@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0^@3oool002<0oooo00<000000?ooo`3oool0o`3o
oonL0?ooo`040000003oool0oooo000000H0oooo0P00000;0?ooo`80000000<0oooo000000000000
1000000C0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0^@3oool002<0oooo00<0
00000?ooo`3oool0o`3ooonL0?ooo`040000003oool0oooo000000P0oooo0P00000;0?ooo`P00000
103oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
^@3oool002<0oooo00<000000?ooo`3oool0o`3ooonL0?ooo`040000003oool0oooo000000X0oooo
0P0000090?ooo`P000001@3oool2000000/0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`2i0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooi`0oooo00@000000?ooo`3oool00000
5@3oool8000000L0oooo0P0000090?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
^@3oool002<0oooo0`00003o0?oooi`0oooo00@000000?ooo`3oool000005@3oool8000000T0oooo
0P0000070?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0^@3oool002<0oooo00<0
00000?ooo`3oool0o`3ooonL0?ooo`040000003oool0oooo00000100oooo00<000000?ooo`3oool0
0P3oool800000180oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo0:80oooo000S0?ooo`030000003oool0oooo0?l0ooooW03oool010000000oooo0?oo
o`00000A0?ooo`8000000P3oool:00000100oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo0:80oooo000S0?ooo`030000003oool0oooo0?l0ooooW03o
ool010000000oooo0?ooo`00000C0?ooo`80000000<0oooo000000000000100000030?ooo`800000
303oool00`000000oooo0000000;0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
XP3oool002<0oooo00<000000?ooo`3oool0o`3ooonL0?ooo`040000003oool0oooo000001D0oooo
0P0000000`3oool000000?ooo`070?ooo`8000002`3oool2000000/0oooo00<000000?ooo`3oool0
503oool00`000000oooo0?ooo`2R0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooi`0oooo00@0
00000?ooo`3oool00000603oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00T0oooo
0`0000090?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0XP3oool002<0oooo00<0
00000?ooo`3oool0o`3ooonL0?ooo`040000003oool0oooo000001P0oooo00<000000?ooo`3oool0
2@3oool2000000T0oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0D0?ooo`03
0000003oool0oooo0:80oooo000S0?ooo`030000003oool0oooo0?l0ooooW03oool010000000oooo
0?ooo`00000H0?ooo`040000003oool0oooo000000X0oooo0P0000050?ooo`H00000203oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo0:80oooo000S0?ooo`030000003oool0oooo0?l0
ooooW`3oool00`000000oooo0?ooo`0F0?ooo`040000003oool0oooo0?ooo`8000002P3oool20000
0080oooo200000070?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0XP3oool002<0
oooo00<000000?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`090?ooo`030000003oool0000000L00000103oool010000000
oooo0?ooo`00000F0?ooo`030000003oool0oooo0:80oooo000S0?ooo`030000003oool0oooo0?l0
ooooW`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00@0oooo0P00000:0?ooo`T0
00001@3oool3000001H0oooo00<000000?ooo`3oool0XP3oool002<0oooo0`00003o0?oooil0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo00P0oooo
200000070?ooo`8000005@3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo08d0oooo
000S0?ooo`030000003oool0oooo0?l0ooooW`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo0140oooo200000070?ooo`040000003oool00000000001<0oooo00<000000?ooo`3oool0
4P3oool00`000000oooo0?ooo`2=0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooil0oooo00<0
00000?ooo`3oool05P3oool00`000000oooo0?ooo`0A0?ooo`P000001`3oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0S@3oool002<0oooo00<00000
0?ooo`3oool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`040?ooo`L000001`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0S@3oool002<0oooo00<000000?ooo`3oool0o`3ooonO0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0303oool2000000H0oooo00<000000?oo
o`3oool00P3oool2000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0S@3oool002<0oooo00<000000?ooo`3o
ool0o`3ooonO0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool03P3oool2000000@0
oooo00<000000?ooo`3oool0103oool2000000<0oooo00<000000?ooo`3oool01P3oool2000000`0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2=0?ooo`008`3oool00`000000oooo
0?ooo`3o0?oooil0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`800000
0P3oool00`000000oooo0?ooo`060?ooo`80000000<0oooo0000003oool02@3oool2000000X0oooo
00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`2=0?ooo`008`3oool00`000000oooo0?oo
o`3o0?oooil0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0D0?ooo`030000003o
ool0oooo00P0oooo0P00000<0?ooo`800000203oool00`000000oooo0?ooo`0B0?ooo`030000003o
ool0oooo08d0oooo000S0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo0?ooo`0D
0?ooo`030000003oool0oooo00L0oooo1P00000C0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`3oool0S@3oool002<0oooo00<000000?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo
01@0oooo00@000000?ooo`3oool000001@3oool800000180oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`2=0?ooo`008`3oool00`000000oooo0?ooo`3o0?oookP0oooo00<000000?oo
o`3oool0503oool01@000000oooo0?ooo`3oool0000000@0oooo2@00000>0?ooo`040000003oool0
oooo000001@0oooo00<000000?ooo`3oool0S@3oool002<0oooo00<000000?ooo`3oool0o`3ooonh
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool00P3oool200000080oooo20000000
0`3oool000000000000=0?ooo`<00000503oool00`000000oooo0?ooo`0<0?ooo`030000003oool0
oooo07h0oooo000S0?ooo`<00000o`3ooonh0?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool0103oool00`000000oooo00000007000000<0oooo00<000000?ooo`3oool0303oool20000
01<0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1n0?ooo`008`3oool00`000000
oooo0?ooo`3o0?oookP0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`050?ooo`T0
0000103oool2000000`0oooo00<000000?ooo`0000004P3oool00`000000oooo0?ooo`0<0?ooo`03
0000003oool0oooo07h0oooo000S0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00H0oooo200000060?ooo`8000002P3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0OP3oool002<0oooo00<0
00000?ooo`3oool0o`3ooonh0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool01`3o
ool6000000T0oooo0P0000080?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303o
ool00`000000oooo0?ooo`1n0?ooo`008`3oool00`000000oooo0?ooo`3o0?oookP0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`090?ooo`030000003oool0000000`0oooo0P000006
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`1n
0?ooo`008`3oool00`000000oooo0?ooo`3o0?oookP0oooo00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo00800000303oool00`000000oooo0?ooo`030?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool02P3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo07h0oooo000S0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000
oooo0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool00P3oool2000000/0
oooo0P0000030?ooo`030000003oool0oooo00H0oooo0P00000:0?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool0OP3oool002<0oooo00<000000?ooo`3oool0o`3ooonh0?ooo`030000
003oool0oooo01@0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo00X0oooo1`0000070?ooo`800000203oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo07h0oooo000S0?ooo`030000003oool0oooo0?l0oooo^03oool00`000000oooo0?oo
o`0D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool04@3oool8000000P0oooo0P00
00060?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0OP3oool000T0oooo10000002
0?ooo`<00000103oool2000000/0oooo00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0
oooo00T0oooo00<000000?ooo`3oool04@3oool800000100oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`1n0?ooo`002@3oool00`000000oooo0?ooo`060?ooo`040000003oool0oooo
00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?oooll0oooo00<00000
0?ooo`3oool02@3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00@0oooo2000000@
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`1U
0?ooo`002P3oool00`000000oooo0?ooo`050?ooo`040000003oool0oooo00000080oooo00<00000
0?ooo`3oool0203oool500000?l0ooooc@3oool00`000000oooo0?ooo`090?ooo`030000003oool0
oooo00/0oooo00<000000?ooo`3oool00`3oool9000000d0oooo00<000000?ooo`0000003P3oool0
0`000000oooo0?ooo`0F0?ooo`030000003oool0oooo06D0oooo000;0?ooo`040000003oool0oooo
0?ooo`<000000`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooc`3o
ool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00`0oooo0P0000030?ooo`P0000000<0
oooo000000000000303oool2000000h0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?oo
o`1U0?ooo`00303oool010000000oooo0?ooo`0000050?ooo`040000003oool0oooo000000X0oooo
00<000000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`08000000<0oooo0P00000;0?ooo`<00000303oool00`000000oooo
0?ooo`0F0?ooo`030000003oool0oooo06D0oooo00090?ooo`040000003oool0oooo00000080oooo
00<000000?ooo`3oool00`3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0
ooooc`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool01P0000060?ooo`8000002@3oool00`000000oooo0?ooo`02000000X0oooo00<000000?ooo`3o
ool05P3oool00`000000oooo0?ooo`1U0?ooo`002P3oool2000000<0oooo100000030?ooo`800000
2`3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?ooo`3oool02@3oool00`000000oooo
0?ooo`0D0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0I@3oool002<0oooo00<0
00000?ooo`3oool0o`3oooo?0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503o
ool00`000000oooo0?ooo`0:0?ooo`8000001P3oool00`000000oooo0?ooo`0<0?ooo`030000003o
ool0oooo01H0oooo00<000000?ooo`3oool0I@3oool002<0oooo00<000000?ooo`3oool0o`3oooo?
0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0503oool2000000d0oooo0P000004
0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0F
0?ooo`030000003oool0oooo06D0oooo000S0?ooo`030000003oool0oooo0?l0ooooc`3oool00`00
0000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00@000000?ooo`00000000003@3oool2
00000080oooo00<000000?ooo`3oool0203oool200000080oooo00<000000?ooo`3oool05P3oool0
0`000000oooo0?ooo`1U0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooll0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`0D0?ooo`040000003oool0oooo0?ooo`800000303oool6
000000X0oooo0`00000H0?ooo`030000003oool0oooo06D0oooo000S0?ooo`030000003oool0oooo
0?l0ooooc`3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo01@0oooo00<000000?oo
o`3oool00`3oool2000000T0oooo2000000;0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`120?ooo`008`3oool00`000000oooo0?ooo`3o0?ooom/0
oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`P000002`3oool00`000000
oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0@P3oool002<0oooo
0`00003o0?ooom/0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0>0?ooo`T00000
2P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0
@P3oool002<0oooo00<000000?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`020?ooo`P0000000<0oooo000000000000203o
ool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0803o
ool00`000000oooo0?ooo`120?ooo`008`3oool00`000000oooo0?ooo`3o0?ooom/0oooo00<00000
0?ooo`3oool0503oool00`000000oooo0?ooo`0:0?ooo`8000000P3oool8000000<0oooo0P000006
0?ooo`030000003oool0oooo00@0oooo0P00000@0?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0@P3oool002<0oooo00<000000?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0303oool00`000000oooo00000007000000D0oooo0P0000040?oo
o`030000003oool0oooo00H0oooo0P00000>0?ooo`030000003oool0oooo0200oooo00<000000?oo
o`3oool0@P3oool002<0oooo00<000000?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool03@3oool8000000P0oooo0P0000020?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0480
oooo000S0?ooo`030000003oool0oooo0?l0oooof`3oool00`000000oooo0?ooo`0D0?ooo`030000
003oool0oooo00l0oooo00@000000?ooo`3oool00000303oool3000001P0oooo00<000000?ooo`3o
ool0803oool00`000000oooo0?ooo`120?ooo`008`3oool00`000000oooo0?ooo`3o0?ooom/0oooo
00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo
0P00000G0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0@P3oool002<0oooo00<0
00000?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool04P3o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0000000h0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo0480oooo000S0?ooo`030000003oool0
oooo0?l0oooof`3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0180oooo00<00000
0?ooo`0000002P3oool7000000d0oooo0P0000050?ooo`030000003oool0oooo0200oooo00<00000
0?ooo`3oool0@P3oool002<0oooo00<000000?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`02000000L0oooo2P00000=0?oo
o`8000000`3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooK0?ooo`030000003oool0oooo01@0
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`020?ooo`8000001@3oool800000080
oooo0P00000=0?ooo`80000000<0oooo0000003oool08@3oool00`000000oooo0?ooo`0>0?ooo`03
0000003oool0oooo0340oooo000S0?ooo`030000003oool0oooo0?l0oooolP3oool00`000000oooo
0?ooo`0B0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`P00000103oool2000000h0oooo
00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340oooo
000S0?ooo`<00000o`3oooob0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3o
ool8000000H0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0P0?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3oooob
0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02@3oool8000000L0oooo0P00000;
0?ooo`040000003oool0oooo000001l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?oo
o`0a0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooo80oooo00<000000?ooo`3oool04P3oool0
0`000000oooo0?ooo`090?ooo`P000002@3oool2000000T0oooo00@000000?ooo`3oool0oooo0P00
000M0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<00000
0?ooo`3oool0o`3oooob0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool02P3oool6
000000`0oooo0P0000070?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340oooo000S0?ooo`030000003oool0oooo
0?l0oooolP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo0`00000?0?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0103oool2000001X0oooo00<000000?oo
o`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooo80
oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
00003P3oool2000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0G0?ooo`03
0000003oool0oooo00h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0
o`3oooob0?ooo`030000003oool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo
0?ooo`0B0?ooo`8000000P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3oooob0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`H000007`3o
ool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340oooo000S0?ooo`030000003oool0
oooo0?l0oooolP3oool00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool04`3oool8000000X0oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0>
0?ooo`030000003oool0oooo0340oooo000S0?ooo`030000003oool0oooo0?l0oooolP3oool00`00
0000oooo0?ooo`0B0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool01`3oool00`00
0000oooo0?ooo`090?ooo`P000002`3oool200000140oooo00<000000?ooo`3oool03P3oool00`00
0000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o0?oooo80oooo00<000000?ooo`3o
ool04P3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00P0oooo0P0000090?ooo`P0
00003@3oool2000000l0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`00
8`3oool300000?l0ooooo`3oool80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
2P3oool2000000L0oooo2P00000=0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0
3P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0oooo203o
ool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool0103o
ool800000080oooo0P00000J0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0<@3o
ool002<0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`P0oooo00<000000?ooo`3oool0303oool0
0`000000oooo0?ooo`0C0?ooo`P00000103oool00`000000oooo0?ooo`0G0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
o`P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0D0?ooo`H000001P3oool20000
00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3oool80?ooo`030000003oool0oooo00`0
oooo00<000000?ooo`3oool04P3oool01@000000oooo0?ooo`3oool0000000/0oooo0P00000=0?oo
o`8000001P3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340oooo000S0?ooo`03
0000003oool0oooo0?l0ooooo`3oool80?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3o
ool04`3oool2000000030?ooo`000000oooo00`0oooo00<000000?ooo`3oool0303oool2000000@0
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo
0?ooo`3o0?ooool0oooo203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01D0oooo
0P00000>0?ooo`8000003P3oool200000080oooo00<000000?ooo`3oool03P3oool00`000000oooo
0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0oooo203oool00`000000oooo0?oo
o`0<0?ooo`030000003oool0oooo01H0oooo0P00000?0?ooo`800000403oool00`000000oooo0?oo
o`0>0?ooo`030000003oool0oooo0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3oool8
0?ooo`030000003oool0oooo00`0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@
0?ooo`800000303oool6000000d0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?oo
o`3oool0o`3ooooo0?ooo`P0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0F0?oo
o`030000003oool0oooo0180oooo00<000000?ooo`3oool0203oool8000000`0oooo00<000000?oo
o`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?ooo`P0oooo00<000000?ooo`3o
ool0303oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01<0oooo0P0000080?ooo`P0
0000303oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0oooo
203oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0>0?ooo`8000001P3oool:000000X0oooo00<000000?ooo`3oool0
<@3oool002<0oooo0`00003o0?ooool0oooo5`3oool00`000000oooo0?ooo`0F0?ooo`030000003o
ool0oooo00D0oooo0P00000@0?ooo`800000103oool800000080oooo0P0000080?ooo`030000003o
ool0oooo0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`030000003oool0
oooo01H0oooo00<000000?ooo`3oool01`3oool200000100oooo00@000000?ooo`3oool0oooo2000
000<0?ooo`030000003oool0oooo0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooolG
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`0>
0?ooo`80000000<0oooo0000000000001P00000<0?ooo`030000003oool0oooo0340oooo000S0?oo
o`030000003oool0oooo0?l0ooooo`3ooolG0?ooo`030000003oool0oooo01H0oooo00<000000?oo
o`3oool0703oool8000000X0oooo00@000000?ooo`3oool00000<`3oool002<0oooo00<000000?oo
o`3oool0o`3ooooo0?oooaL0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0N0?oo
o`030000003oool0000000h0oooo0`00000c0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0
oooo5`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3o
ool03@3oool200000100oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0
o`3ooooo0?oooaL0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0@0?ooo`800000
3P3oool3000000h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooaL0oooo00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0B0?ooo`800000303o
ool00`000000oooo0?ooo`02000000X0oooo1P00000`0?ooo`008`3oool00`000000oooo0?ooo`3o
0?ooool0oooo5`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo01@0oooo0P00000:
0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool01P3oool8000002l0oooo000:0?oo
o`800000103oool2000000@0oooo0P00000;0?ooo`030000003oool0oooo0?l0ooooo`3ooolG0?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`030?oo
o`8000001P3oool8000002l0oooo00090?ooo`040000003oool0oooo00000080oooo00@000000?oo
o`3oool000000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3o
oolG0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`050?ooo`800000103oool8000002l0oooo000<0?ooo`040000003oool0oooo00000080oooo00@0
00000?ooo`3oool000000P3oool00`000000oooo0?ooo`080?ooo`D00000o`3ooooo0?oooaD0oooo
00<000000?ooo`3oool05P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo
00@000000?ooo`3oool0oooo2000000_0?ooo`002P3oool2000000<0oooo00@000000?ooo`3oool0
00000P3oool010000000oooo0?ooo`00000:0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`080?oo
o`80000000<0oooo0000000000001P00000_0?ooo`00303oool010000000oooo0?ooo`0000020?oo
o`040000003oool0oooo00000080oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o
0?ooool0oooo<03oool00`000000oooo0?ooo`0K0?ooo`8000000`3oool00`000000oooo0?ooo`0:
0?ooo`T00000;`3oool000T0oooo00@000000?ooo`3oool000000P3oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo000000X0oooo00<000000?ooo`3oool0o`3ooooo0?oooc00oooo
00<000000?ooo`3oool07@3oool2000000030?ooo`000000oooo00d0oooo1P00000`0?ooo`002P3o
ool2000000@0oooo0P0000040?ooo`8000002`3oool00`000000oooo0?ooo`3o0?ooool0oooo<03o
ool00`000000oooo0?ooo`0O0?ooo`800000403oool00`000000oooo0?ooo`0a0?ooo`008`3oool0
0`000000oooo0?ooo`3o0?ooool0oooo<03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oc00oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo
0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`030000003oool0oooo0200
oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo0340
oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3oool`0?ooo`030000003oool0oooo0200oooo
00<000000?ooo`3oool00`3oool2000000T0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<0
00000?ooo`3oool0o`3ooooo0?oooc00oooo00<000000?ooo`3oool0803oool00`000000oooo0?oo
o`050?ooo`8000001`3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o
0?ooool0oooo<03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00L0oooo0P000005
0?ooo`030000003oool0oooo0340oooo000S0?ooo`<00000o`3ooooo0?oooc00oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340oooo000S0?ooo`03
0000003oool0oooo0?l0ooooo`3oool`0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0oooo
<03oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo00d0oooo0P00000c0?ooo`008`3o
ool00`000000oooo0?ooo`3o0?ooool0ooooD`3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomC0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
oe<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000
oooo0?ooo`3o0?ooool0ooooD`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340
oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomC0?ooo`030000003oool0oooo00h0oooo
00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo00<0
00000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool00`000000oooo0?ooo`3o
0?ooool0ooooD`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0oooo0340oooo000S0?oo
o`030000003oool0oooo0?l0ooooo`3ooomC0?ooo`030000003oool0oooo00h0oooo00<000000?oo
o`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oooe<0oooo00<000000?ooo`3o
ool03P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool300000?l0ooooo`3ooomC0?ooo`030000
003oool0oooo00h0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3o
oooo0?oooe<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0a0?ooo`008`3oool0
0`000000oooo0?ooo`3o0?ooool0ooooD`3oool00`000000oooo0?ooo`0>0?ooo`030000003oool0
oooo0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo
0340oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo0340
oooo000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo0340oooo
000S0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo0340oooo000S
0?ooo`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo0340oooo000S0?oo
o`030000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo0340oooo000S0?ooo`03
0000003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo0340oooo000S0?ooo`030000
003oool0oooo0?l0ooooo`3ooomT0?ooo`030000003oool0oooo0340oooo000S0?ooo`<00000o`3o
oooo0?ooof@0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo
0?ooof@0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oo
of@0oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?ooof@0
oooo00<000000?ooo`3oool0<@3oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oooiP0oooo
000S0?ooo`030000003oool0oooo0?l0ooooo`3ooonH0?ooo`008`3oool00`000000oooo0?ooo`3o
0?ooool0ooooV03oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oooiP0oooo000S0?ooo`03
0000003oool0oooo0?l0ooooo`3ooonH0?ooo`008`3oool00`000000oooo0?ooo`3o0?ooool0oooo
V03oool002<0oooo00<000000?ooo`3oool0o`3ooooo0?oooiP0oooo000S0?ooo`030000003oool0
oooo0?l0ooooo`3ooonH0?ooo`008`3oool300000?l0ooooo`3ooonH0?ooo`008`3oool00`000000
oooo0?ooo`3o0?ooool0ooooV03oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo003o
0?ooool0oooo_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0oooo
_P3oool00?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo003o0?ooool0oooo_P3oool00?l0
ooooo`3ooonn0?ooo`00o`3ooom30?ooo`80000000@0oooo0000003oool0oooo0P0000000`3oool0
00000?ooo`020?ooo`8000000`3oool2000000030?ooo`000000oooo00<00000103oool3000000@0
oooo0P00003o0?oooe@0oooo003o0?oood80oooo00@000000?ooo`3oool000000P3oool010000000
oooo0?ooo`0000030?ooo`060000003oool0oooo0000003oool000000P3oool00`000000oooo0?oo
o`030?ooo`040000003oool0oooo000000H0oooo00@000000?ooo`3oool00000o`3ooomC0?ooo`00
o`3ooom20?ooo`040000003oool0oooo000000<0oooo0`0000030?ooo`030000003oool0oooo00<0
oooo0`0000030?ooo`8000000`3oool3000000@0oooo00<000000?ooo`3oool0o`3ooomD0?ooo`00
o`3ooom20?ooo`040000003oool0oooo000000D0oooo00D000000?ooo`3oool0oooo000000070?oo
o`040000003oool0oooo000000D0oooo00@000000?ooo`3oool000000`3oool00`000000oooo0?oo
o`3o0?oooe@0oooo003o0?oood<0oooo0`0000030?ooo`8000000`3oool4000000<0oooo0P000004
0?ooo`<000000`3oool2000000<0oooo1000003o0?oooe@0oooo003o0?ooodD0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo0?l0ooooE03oool00200
oooo0P00003o0?ooob80oooo0P0000090?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3o
ool0o`3ooomD0?ooo`008P3oool00`000000oooo0?ooo`3o0?ooool0ooooV@3oool00280oooo0P00
003o0?ooool0ooooVP3oool00240oooo00@000000?ooo`3oool00000o`3ooooo0?oooiT0oooo000Q
0?ooo`040000003oool0oooo00000?l0ooooo`3ooonI0?ooo`008@3oool010000000oooo0?ooo`00
003o0?ooool0ooooV@3oool00200oooo0P0000000`3oool000000000003o0?ooool0ooooV@3oool0
0?l0ooooo`3ooonn0?ooo`00o`3ooooo0?oookh0oooo0000\
\>"],
  ImageRangeCache->{{{0, 699}, {431.625, 0}} -> {-0.447813, -14.9581, \
0.0127787, 0.877239}}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Calculations", "Section"],

Cell[BoxData[{
    \(\(r1 = 0.03;\)\), "\[IndentingNewLine]", 
    \(\(r2 = 0.04;\)\), "\[IndentingNewLine]", 
    \(\(r3 = 0.05;\)\)}], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(help = 125\ \(m\/32\) \((R\/\(r\ n\ \[Mu]\))\)\^2\)], "Input"],

Cell[BoxData[
    \(\(125\ m\ R\^2\)\/\(32\ n\^2\ r\^2\ \[Mu]\^2\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp[m_, \ \[CapitalDelta]m_, \ R_, \ \[CapitalDelta]R_, \ 
        r_, \ \[CapitalDelta]r_, \ 
        n_, \ \[CapitalDelta]n_, \ \[Mu]_] = {help, \@\(\((D[help, \ m]\ \
\[CapitalDelta]m)\)\^2 + \((D[help, \ R]\ \[CapitalDelta]R)\)\^2 + \((D[help, \
\ r]\ \[CapitalDelta]r)\)\^2 + \((D[help, \ n]\ \[CapitalDelta]n)\)\^2\)}\)], \
"Input"],

Cell[BoxData[
    \({\(125\ m\ R\^2\)\/\(32\ n\^2\ r\^2\ \[Mu]\^2\), \@\(\(15625\ R\^4\ \
\[CapitalDelta]m\^2\)\/\(1024\ n\^4\ r\^4\ \[Mu]\^4\) + \(15625\ m\^2\ R\^4\ \
\[CapitalDelta]n\^2\)\/\(256\ n\^6\ r\^4\ \[Mu]\^4\) + \(15625\ m\^2\ R\^4\ \
\[CapitalDelta]r\^2\)\/\(256\ n\^4\ r\^6\ \[Mu]\^4\) + \(15625\ m\^2\ R\^2\ \
\[CapitalDelta]R\^2\)\/\(256\ n\^4\ r\^4\ \[Mu]\^4\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp[1] = 
      sp[b /. parameter, \[CapitalDelta]b /. parameter, 0.2, 0.001, r1, \ 
        0.0005, \ 154, 0.1, 1.26\ \[Times]\ 10\^\(-6\)]\)], "Input"],

Cell[BoxData[
    \({1.7851662850572433`*^11, 8.025207289929751`*^9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp[2] = 
      sp[b /. parameter2, \[CapitalDelta]b /. parameter, 0.2, 0.001, r2, \ 
        0.0005, \ 154, 0.1, 1.26\ \[Times]\ 10\^\(-6\)]\)], "Input"],

Cell[BoxData[
    \({1.8705534085568185`*^11, 5.794425329789597`*^9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp[3] = 
      sp[b /. parameter3, \[CapitalDelta]b /. parameter, 0.2, 0.001, r3, \ 
        0.0005, \ 154, 0.1, 1.26\ \[Times]\ 10\^\(-6\)]\)], "Input"],

Cell[BoxData[
    \({1.9012127971258704`*^11, 4.6337642440000725`*^9}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sp = {\[Sum]\+\(i = 1\)\%3\(\( sp[
                    i]\)\[LeftDoubleBracket]1\[RightDoubleBracket]\/\(sp[i]\)\
\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\)/\(\[Sum]\+\(i = 1\)\%3 \
1\/\(sp[i]\)\[LeftDoubleBracket]2\[RightDoubleBracket]\^2\), 
        1/\@\(\[Sum]\+\(i = 1\)\%3 1\/\(sp[i]\)\[LeftDoubleBracket]2\
\[RightDoubleBracket]\^2\)}\)], "Input"],

Cell[BoxData[
    \({1.8716644588629782`*^11, 3.298991504888782`*^9}\)], "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for X",
ScreenRectangle->{{0, 1400}, {0, 1050}},
ScreenStyleEnvironment->"Working",
WindowSize->{840, 935},
WindowMargins->{{Automatic, 267}, {Automatic, 17}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "home", "goerz", \
"cpprakt"}, "cpgoerz_mi_01.nb.ps", CharacterEncoding -> "iso8859-1"],
"Magnification"->1}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 34, 0, 98, "Title"],
Cell[1813, 55, 48, 3, 50, "Text"],

Cell[CellGroupData[{
Cell[1886, 62, 27, 0, 74, "Section"],

Cell[CellGroupData[{
Cell[1938, 66, 32, 0, 28, "Subsubsection"],
Cell[1973, 68, 77, 1, 27, "Input"],
Cell[2053, 71, 64, 1, 27, "Input"],
Cell[2120, 74, 66, 1, 27, "Input"],
Cell[2189, 77, 56, 1, 27, "Input"],
Cell[2248, 80, 64, 1, 27, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2349, 86, 64, 0, 22, "Subsubsection"],
Cell[2416, 88, 472, 9, 191, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[2925, 102, 39, 0, 22, "Subsubsection"],
Cell[2967, 104, 156, 3, 32, "Text"],

Cell[CellGroupData[{
Cell[3148, 111, 92, 1, 27, "Input"],
Cell[3243, 114, 608, 9, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3888, 128, 93, 1, 27, "Input"],
Cell[3984, 131, 602, 9, 91, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4623, 145, 93, 1, 27, "Input"],
Cell[4719, 148, 593, 8, 91, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5373, 163, 28, 0, 74, "Section"],

Cell[CellGroupData[{
Cell[5426, 167, 65, 0, 28, "Subsubsection"],
Cell[5494, 169, 5946, 96, 880, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[11477, 270, 84, 1, 22, "Subsubsection"],
Cell[11564, 273, 5955, 95, 866, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[17556, 373, 78, 0, 22, "Subsubsection"],
Cell[17637, 375, 3551, 60, 695, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[21225, 440, 58, 0, 22, "Subsubsection"],
Cell[21286, 442, 100, 3, 32, "Text"],
Cell[21389, 447, 190, 3, 27, "Input"],
Cell[21582, 452, 216, 4, 50, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21835, 461, 39, 0, 22, "Subsubsection"],
Cell[21877, 463, 148, 4, 45, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[22074, 473, 30, 0, 44, "Section"],

Cell[CellGroupData[{
Cell[22129, 477, 36, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[22190, 481, 66, 1, 27, "Input"],
Cell[22259, 484, 54, 1, 23, "Print"],
Cell[22316, 487, 171, 3, 23, "Print"],
Cell[22490, 492, 372, 10, 41, "Print"],
Cell[22865, 504, 45, 1, 23, "Print"],
Cell[22913, 507, 249, 5, 23, "Print"],
Cell[23165, 514, 259, 5, 23, "Print"],
Cell[23427, 521, 265, 5, 23, "Print"],
Cell[23695, 528, 45, 1, 23, "Print"],
Cell[23743, 531, 220, 4, 25, "Print"],
Cell[23966, 537, 294, 6, 42, "Print"],
Cell[24263, 545, 309, 6, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24609, 556, 68, 1, 27, "Input"],
Cell[24680, 559, 54, 1, 23, "Print"],
Cell[24737, 562, 171, 3, 23, "Print"],
Cell[24911, 567, 370, 10, 41, "Print"],
Cell[25284, 579, 45, 1, 23, "Print"],
Cell[25332, 582, 248, 5, 23, "Print"],
Cell[25583, 589, 259, 5, 23, "Print"],
Cell[25845, 596, 265, 5, 23, "Print"],
Cell[26113, 603, 45, 1, 23, "Print"],
Cell[26161, 606, 221, 4, 25, "Print"],
Cell[26385, 612, 294, 6, 42, "Print"],
Cell[26682, 620, 308, 6, 27, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27027, 631, 68, 1, 27, "Input"],
Cell[27098, 634, 54, 1, 23, "Print"],
Cell[27155, 637, 171, 3, 23, "Print"],
Cell[27329, 642, 372, 10, 41, "Print"],
Cell[27704, 654, 45, 1, 23, "Print"],
Cell[27752, 657, 250, 5, 23, "Print"],
Cell[28005, 664, 260, 5, 23, "Print"],
Cell[28268, 671, 266, 5, 23, "Print"],
Cell[28537, 678, 45, 1, 23, "Print"],
Cell[28585, 681, 221, 4, 25, "Print"],
Cell[28809, 687, 294, 6, 42, "Print"],
Cell[29106, 695, 310, 6, 27, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[29465, 707, 29, 0, 28, "Subsubsection"],

Cell[CellGroupData[{
Cell[29519, 711, 680, 12, 107, "Input"],
Cell[30202, 725, 73961, 1380, 441, 9911, 586, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[104224, 2112, 31, 0, 74, "Section"],
Cell[104258, 2114, 145, 3, 59, "Input"],

Cell[CellGroupData[{
Cell[104428, 2121, 82, 1, 46, "Input"],
Cell[104513, 2124, 80, 1, 48, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104630, 2130, 357, 6, 53, "Input"],
Cell[104990, 2138, 394, 5, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105421, 2148, 172, 3, 31, "Input"],
Cell[105596, 2153, 82, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105715, 2159, 173, 3, 31, "Input"],
Cell[105891, 2164, 82, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106010, 2170, 173, 3, 31, "Input"],
Cell[106186, 2175, 83, 1, 29, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106306, 2181, 379, 6, 67, "Input"],
Cell[106688, 2189, 82, 1, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

